# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DIRGEN_METADATA = Metadata(
    id="111662ebc02bd748b7609e8b39562fb928767bbb.boutiques",
    name="dirgen",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class DirgenConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class DirgenOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dirgen(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dirs: OutputPathType
    """the text file to write the directions to, as [ az el ] pairs."""


def dirgen(
    ndir: int,
    dirs: str,
    power: int | None = None,
    niter: int | None = None,
    restarts: int | None = None,
    unipolar: bool = False,
    cartesian: bool = False,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[DirgenConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> DirgenOutputs:
    """
    Generate a set of uniformly distributed directions using a bipolar electrostatic
    repulsion model.
    
    Directions are distributed by analogy to an electrostatic repulsion system,
    with each direction corresponding to a single electrostatic charge (for
    -unipolar), or a pair of diametrically opposed charges (for the default
    bipolar case). The energy of the system is determined based on the Coulomb
    repulsion, which assumes the form 1/r^power, where r is the distance between
    any pair of charges, and p is the power assumed for the repulsion law
    (default: 1). The minimum energy state is obtained by gradient descent.
    
    References:
    
    Jones, D.; Horsfield, M. & Simmons, A. Optimal strategies for measuring
    diffusion in anisotropic systems by magnetic resonance imaging. Magnetic
    Resonance in Medicine, 1999, 42: 515-525
    
    Papadakis, N. G.; Murrills, C. D.; Hall, L. D.; Huang, C. L.-H. & Adrian
    Carpenter, T. Minimal gradient encoding for robust estimation of diffusion
    anisotropy. Magnetic Resonance Imaging, 2000, 18: 671-679.
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        ndir: the number of directions to generate.
        dirs: the text file to write the directions to, as [ az el ] pairs.
        power: specify exponent to use for repulsion power law (default: 1).\
            This must be a power of 2 (i.e. 1, 2, 4, 8, 16, ...).
        niter: specify the maximum number of iterations to perform (default:\
            10000).
        restarts: specify the number of restarts to perform (default: 10).
        unipolar: optimise assuming a unipolar electrostatic repulsion model\
            rather than the bipolar model normally assumed in DWI.
        cartesian: Output the directions in Cartesian coordinates [x y z]\
            instead of [az el].
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DirgenOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DIRGEN_METADATA)
    cargs = []
    cargs.append("dirgen")
    if power is not None:
        cargs.extend([
            "-power",
            str(power)
        ])
    if niter is not None:
        cargs.extend([
            "-niter",
            str(niter)
        ])
    if restarts is not None:
        cargs.extend([
            "-restarts",
            str(restarts)
        ])
    if unipolar:
        cargs.append("-unipolar")
    if cartesian:
        cargs.append("-cartesian")
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(str(ndir))
    cargs.append(dirs)
    ret = DirgenOutputs(
        root=execution.output_file("."),
        dirs=execution.output_file(dirs),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DIRGEN_METADATA",
    "DirgenConfig",
    "DirgenOutputs",
    "dirgen",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_RGB_LH_METADATA = Metadata(
    id="8a27176b135c7e00506bbb223dc33d4f8b5c331f.boutiques",
    name="morph_rgb-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphRgbLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_rgb_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_rgb_lh(
    subject_id: str,
    runner: Runner | None = None,
) -> MorphRgbLhOutputs:
    """
    Tool for working with and generating RGB images of morphometric data for the
    left hemisphere in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: The subject ID to process. This refers to the sub-directory\
            within $SUBJECTS_DIR containing the FreeSurfer processed data for the\
            subject.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphRgbLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_RGB_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "morph_rgb" + subject_id
    ])
    ret = MorphRgbLhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_RGB_LH_METADATA",
    "MorphRgbLhOutputs",
    "morph_rgb_lh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POSSUM_PLOT_METADATA = Metadata(
    id="8ed3fa6e50d07f3853fcec9ca53f667a78d048a0.boutiques",
    name="possum_plot",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class PossumPlotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `possum_plot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_plots: OutputPathType
    """Output plot images from POSSUM"""


def possum_plot(
    input_file: InputPathType,
    output_basename: str,
    runner: Runner | None = None,
) -> PossumPlotOutputs:
    """
    Tool for plotting results from POSSUM simulations in FSL.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: Input file from POSSUM simulation (e.g.\
            simulation_results.txt).
        output_basename: Basename for output files (e.g. plot_output).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PossumPlotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POSSUM_PLOT_METADATA)
    cargs = []
    cargs.append("possum_plot.py")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_basename)
    ret = PossumPlotOutputs(
        root=execution.output_file("."),
        output_plots=execution.output_file(output_basename + "_*.png"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POSSUM_PLOT_METADATA",
    "PossumPlotOutputs",
    "possum_plot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DEDGEDOG_METADATA = Metadata(
    id="9e99566b54cfbbe32a2b727088bdd1879b2a5924.boutiques",
    name="3dedgedog",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dedgedogOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dedgedog(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_edge: OutputPathType
    """Output edge dataset"""
    out_dog: OutputPathType
    """Output difference of Gaussian dataset"""
    out_edt2: OutputPathType
    """Output Euclidean Distance Transform squared dataset"""
    out_blur_inner: OutputPathType
    """Output inner Gaussian blurred dataset"""
    out_blur_outer: OutputPathType
    """Output outer Gaussian blurred dataset"""


def v_3dedgedog(
    input_: InputPathType,
    prefix: str,
    mask: InputPathType | None = None,
    automask: str | None = None,
    sigma_rad: float | None = None,
    sigma_nvox: float | None = None,
    ratio_sigma: float | None = None,
    output_intermed: bool = False,
    edge_bnd_nn: float | None = None,
    edge_bnd_side: str | None = None,
    edge_bnd_scale: bool = False,
    only2d: str | None = None,
    runner: Runner | None = None,
) -> V3dedgedogOutputs:
    """
    Calculate edges in an image using the Difference of Gaussians (DOG) method with
    extensions/tweaks of the Marr-Hildreth algorithm.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Input dataset.
        prefix: Output prefix name.
        mask: Mask dataset applied after Euclidean Distance Transform\
            calculation.
        automask: Calculate mask automatically. Optionally, you can provide an\
            integer X to dilate the initial automask X times (e.g., -automask+X).
        sigma_rad: Radius for 'inner' Gaussian, in mm; must be greater than 0\
            (default: 1.40).
        sigma_nvox: Define radius for 'inner' Gaussian by providing a\
            multiplicative factor for voxel edge length greater than 0 (default:\
            use sigma_rad).
        ratio_sigma: Ratio of inner and outer Gaussian sigma values (default:\
            1.40).
        output_intermed: Output intermediate datasets: DOG, EDT2, BLURS\
            (default: not output).
        edge_bnd_nn: Nearest neighbor (NN) value for connectedness of\
            boundaries; must be 1 (face only), 2 (face+edge), or 3 (face+edge+node)\
            (default: 1).
        edge_bnd_side: Specify boundary layer to use: NEG, POS, BOTH, BOTH_SIGN\
            (default: NEG).
        edge_bnd_scale: Scale edge values to have relative magnitude between 0\
            and 100 (default: edge locations have value=1).
        only2d: Calculate edges in 2D per plane specified by SLI: 'axi', 'cor',\
            'sag'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dedgedogOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DEDGEDOG_METADATA)
    cargs = []
    cargs.append("3dedgedog")
    cargs.append(execution.input_file(input_))
    cargs.append(prefix)
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if automask is not None:
        cargs.extend([
            "-automask",
            automask
        ])
    if sigma_rad is not None:
        cargs.extend([
            "-sigma_rad",
            str(sigma_rad)
        ])
    if sigma_nvox is not None:
        cargs.extend([
            "-sigma_nvox",
            str(sigma_nvox)
        ])
    if ratio_sigma is not None:
        cargs.extend([
            "-ratio_sigma",
            str(ratio_sigma)
        ])
    if output_intermed:
        cargs.append("-output_intermed")
    if edge_bnd_nn is not None:
        cargs.extend([
            "-edge_bnd_NN",
            str(edge_bnd_nn)
        ])
    if edge_bnd_side is not None:
        cargs.extend([
            "-edge_bnd_side",
            edge_bnd_side
        ])
    if edge_bnd_scale:
        cargs.append("-edge_bnd_scale")
    if only2d is not None:
        cargs.extend([
            "-only2D",
            only2d
        ])
    ret = V3dedgedogOutputs(
        root=execution.output_file("."),
        out_edge=execution.output_file(prefix + "_edge.nii.gz"),
        out_dog=execution.output_file(prefix + "_dog.nii.gz"),
        out_edt2=execution.output_file(prefix + "_edt2.nii.gz"),
        out_blur_inner=execution.output_file(prefix + "_blur_inner.nii.gz"),
        out_blur_outer=execution.output_file(prefix + "_blur_outer.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dedgedogOutputs",
    "V_3DEDGEDOG_METADATA",
    "v_3dedgedog",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_CREATE_SPHERE_METADATA = Metadata(
    id="4f2f655e81d545740a448403ba6bbaff1b89f0a6.boutiques",
    name="surface-create-sphere",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceCreateSphereOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_create_sphere(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    sphere_out: OutputPathType
    """the output sphere"""


def surface_create_sphere(
    num_vertices: int,
    sphere_out: str,
    runner: Runner | None = None,
) -> SurfaceCreateSphereOutputs:
    """
    Generate a sphere with consistent vertex areas.
    
    Generates a sphere by regularly dividing the triangles of an icosahedron, to
    come as close to the desired number of vertices as possible, and modifying
    it to have very similar vertex areas for all vertices. To generate a pair of
    vertex-matched left and right spheres, use this command, then
    -surface-flip-lr to generate the other sphere, then -set-structure on each.
    For example:
    
    $ wb_command -surface-create-sphere 6000 Sphere.6k.R.surf.gii
    $ wb_command -surface-flip-lr Sphere.6k.R.surf.gii Sphere.6k.L.surf.gii
    $ wb_command -set-structure Sphere.6k.R.surf.gii CORTEX_RIGHT
    $ wb_command -set-structure Sphere.6k.L.surf.gii CORTEX_LEFT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        num_vertices: desired number of vertices.
        sphere_out: the output sphere.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCreateSphereOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_CREATE_SPHERE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-create-sphere")
    cargs.append(str(num_vertices))
    cargs.append(sphere_out)
    ret = SurfaceCreateSphereOutputs(
        root=execution.output_file("."),
        sphere_out=execution.output_file(sphere_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_CREATE_SPHERE_METADATA",
    "SurfaceCreateSphereOutputs",
    "surface_create_sphere",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TALAIRACH2_METADATA = Metadata(
    id="200a3bdd395b88d5b03ecdc9cf8d79338e29d2f2.boutiques",
    name="talairach2",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Talairach2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `talairach2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def talairach2(
    subject_id: str,
    mgz_flag: str | None = None,
    runner: Runner | None = None,
) -> Talairach2Outputs:
    """
    Tool for processing and converting talairach transformation files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject identifier for the talairach transformation.
        mgz_flag: Flag to indicate whether mgz format is used.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Talairach2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TALAIRACH2_METADATA)
    cargs = []
    cargs.append("talairach2")
    cargs.append(subject_id)
    if mgz_flag is not None:
        cargs.append(mgz_flag)
    ret = Talairach2Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TALAIRACH2_METADATA",
    "Talairach2Outputs",
    "talairach2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_ANATOMI_CUTS_METADATA = Metadata(
    id="b3ae6660625cd9a73409943ca03518bf3c1e8760.boutiques",
    name="dmri_AnatomiCuts",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriAnatomiCutsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_anatomi_cuts(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_vtk: OutputPathType
    """Output VTK file of the segmentation"""


def dmri_anatomi_cuts(
    segmentation_file: InputPathType,
    fiber_file: InputPathType,
    clusters: float,
    points: float,
    fibers_eigen: float,
    output_folder: str,
    direction_flag: typing.Literal["s", "d", "a", "o"],
    runner: Runner | None = None,
) -> DmriAnatomiCutsOutputs:
    """
    AnatomiCuts tool for DTI fibers segmentation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        segmentation_file: Segmentation file.
        fiber_file: VTK fiber file.
        clusters: Number of clusters.
        points: Number of points.
        fibers_eigen: Number of fibers for eigen decomposition.
        output_folder: Output folder.
        direction_flag: Direction flag: 's' for straight, 'd' for diagonal, 'a'\
            for all, 'o' for none.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriAnatomiCutsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_ANATOMI_CUTS_METADATA)
    cargs = []
    cargs.append("dmri_AnatomiCuts")
    cargs.extend([
        "-s",
        execution.input_file(segmentation_file)
    ])
    cargs.extend([
        "-f",
        execution.input_file(fiber_file)
    ])
    cargs.extend([
        "-c",
        str(clusters)
    ])
    cargs.extend([
        "-n",
        str(points)
    ])
    cargs.extend([
        "-e",
        str(fibers_eigen)
    ])
    cargs.extend([
        "-o",
        output_folder
    ])
    cargs.extend([
        "-d",
        direction_flag
    ])
    ret = DmriAnatomiCutsOutputs(
        root=execution.output_file("."),
        output_vtk=execution.output_file(output_folder + "/output.vtk"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_ANATOMI_CUTS_METADATA",
    "DmriAnatomiCutsOutputs",
    "dmri_anatomi_cuts",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SWE_METADATA = Metadata(
    id="0ee1b5913ae7cf862cb7ffe561615ef0a1ad863c.boutiques",
    name="swe",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SweOutputs(typing.NamedTuple):
    """
    Output object returned when calling `swe(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    logp_img: OutputPathType
    """Output -log_10(p) images"""
    corrp_img: OutputPathType
    """Output voxel-corrected p-value images"""
    raw_img: OutputPathType
    """Output raw voxelwise statistic images"""
    equiv_img: OutputPathType
    """Output equivalent z or chi-squared statistic images"""
    dof_img: OutputPathType
    """Output effective number of degrees of freedom images"""
    uncorrp_img: OutputPathType
    """Output uncorrected p-value images"""
    null_dist_file: OutputPathType
    """Output null distribution text files"""
    glm_output_file: OutputPathType
    """Output GLM information (pe, cope, & varcope)"""


def swe(
    input_file: InputPathType,
    output_root: str,
    design_mat: InputPathType,
    design_con: InputPathType,
    design_sub: InputPathType,
    mask: InputPathType | None = None,
    fcon: InputPathType | None = None,
    modified: bool = False,
    wild_bootstrap: bool = False,
    logp: bool = False,
    nboot: float | None = 999,
    corrp: bool = False,
    fonly: bool = False,
    tfce: bool = False,
    tfce_2d: bool = False,
    cluster_t: float | None = None,
    cluster_t_mass: float | None = None,
    cluster_f: float | None = None,
    cluster_f_mass: float | None = None,
    quiet: bool = False,
    raw: bool = False,
    equiv: bool = False,
    dof: bool = False,
    uncorr_p: bool = False,
    null_dist: bool = False,
    no_rc_mask: bool = False,
    seed: float | None = None,
    tfce_h: float | None = 2,
    tfce_d: float | None = None,
    tfce_e: float | None = 0.5,
    tfce_c: float | None = 6,
    voxelwise_ev: list[float] | None = None,
    voxelwise_evs: list[InputPathType] | None = None,
    glm_output: bool = False,
    runner: Runner | None = None,
) -> SweOutputs:
    """
    SwE (summary statistics and voxelwise statistical analyses tool for FSL).
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: 4D input image.
        output_root: Output file root name.
        design_mat: Design matrix file.
        design_con: T contrasts file.
        design_sub: Subjects file.
        mask: Mask image.
        fcon: F contrasts file.
        modified: Use the modified 'Homogeneous' SwE instead of the classic\
            'Heterogeneous' SwE.
        wild_bootstrap: Inference using a non-parametric Wild Bootstrap\
            procedure.
        logp: Return -log_10(p) images instead of 1-p images.
        nboot: Number of bootstraps (default 999).
        corrp: Output voxelwise corrected p-value images.
        fonly: Calculate f-statistics only.
        tfce: Threshold-Free Cluster Enhancement.
        tfce_2d: Threshold-Free Cluster Enhancement with 2D optimisation, e.g.\
            for TBSS data (H=2, E=1, C=26).
        cluster_t: Cluster-extent-based inference for t-contrasts with\
            specified cluster-forming threshold (z-score if >= 1, uncorrected\
            p-value if < 1).
        cluster_t_mass: Cluster-mass-based inference for t-contrasts with\
            specified cluster-forming threshold (z-score if >= 1, uncorrected\
            p-value if < 1).
        cluster_f: Cluster-extent-based inference for f-contrasts with\
            specified cluster-forming threshold (chi-squared-score if >= 1,\
            uncorrected p-value if < 1).
        cluster_f_mass: Cluster-mass-based inference for f-contrasts with\
            specified cluster-forming threshold (chi-squared-score if >= 1,\
            uncorrected p-value if < 1).
        quiet: Switch off diagnostic messages.
        raw: Output raw voxelwise statistic images.
        equiv: Output equivalent z or chi-squared statistic images.
        dof: Output effective number of degrees of freedom images.
        uncorr_p: Output uncorrected p-value images.
        null_dist: Output null distribution text files.
        no_rc_mask: Don't remove constant voxels from mask.
        seed: Specific integer seed for random number generator.
        tfce_h: TFCE height parameter (default=2).
        tfce_d: TFCE delta parameter override.
        tfce_e: TFCE extent parameter (default=0.5).
        tfce_c: TFCE connectivity (6 or 26; default=6).
        voxelwise_ev: List of numbers indicating voxelwise EVs position in the\
            design matrix.
        voxelwise_evs: List of 4D images containing voxelwise EVs.
        glm_output: Output GLM information (pe, cope, & varcope).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SweOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SWE_METADATA)
    cargs = []
    cargs.append("swe")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-o",
        output_root
    ])
    cargs.extend([
        "-d",
        execution.input_file(design_mat)
    ])
    cargs.extend([
        "-t",
        execution.input_file(design_con)
    ])
    cargs.extend([
        "-s",
        execution.input_file(design_sub)
    ])
    if mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask)
        ])
    if fcon is not None:
        cargs.extend([
            "-f",
            execution.input_file(fcon)
        ])
    if modified:
        cargs.append("--modified")
    if wild_bootstrap:
        cargs.append("--wb")
    if logp:
        cargs.append("--logp")
    if nboot is not None:
        cargs.extend([
            "-n",
            str(nboot)
        ])
    if corrp:
        cargs.append("-x")
    if fonly:
        cargs.append("--fonly")
    if tfce:
        cargs.append("-T")
    if tfce_2d:
        cargs.append("--T2")
    if cluster_t is not None:
        cargs.extend([
            "-c",
            str(cluster_t)
        ])
    if cluster_t_mass is not None:
        cargs.extend([
            "-C",
            str(cluster_t_mass)
        ])
    if cluster_f is not None:
        cargs.extend([
            "-F",
            str(cluster_f)
        ])
    if cluster_f_mass is not None:
        cargs.extend([
            "-S",
            str(cluster_f_mass)
        ])
    if quiet:
        cargs.append("--quiet")
    if raw:
        cargs.append("-R")
    if equiv:
        cargs.append("-E")
    if dof:
        cargs.append("-D")
    if uncorr_p:
        cargs.append("--uncorrp")
    if null_dist:
        cargs.append("-N")
    if no_rc_mask:
        cargs.append("--norcmask")
    if seed is not None:
        cargs.extend([
            "--seed",
            str(seed)
        ])
    if tfce_h is not None:
        cargs.extend([
            "--tfce_H",
            str(tfce_h)
        ])
    if tfce_d is not None:
        cargs.extend([
            "--tfce_D",
            str(tfce_d)
        ])
    if tfce_e is not None:
        cargs.extend([
            "--tfce_E",
            str(tfce_e)
        ])
    if tfce_c is not None:
        cargs.extend([
            "--tfce_C",
            str(tfce_c)
        ])
    if voxelwise_ev is not None:
        cargs.extend([
            "--vxl",
            *map(str, voxelwise_ev)
        ])
    if voxelwise_evs is not None:
        cargs.extend([
            "--vxf",
            *[execution.input_file(f) for f in voxelwise_evs]
        ])
    if glm_output:
        cargs.append("--glm_output")
    ret = SweOutputs(
        root=execution.output_file("."),
        logp_img=execution.output_file(output_root + "_logp.nii.gz"),
        corrp_img=execution.output_file(output_root + "_corrp.nii.gz"),
        raw_img=execution.output_file(output_root + "_raw.nii.gz"),
        equiv_img=execution.output_file(output_root + "_equiv.nii.gz"),
        dof_img=execution.output_file(output_root + "_dof.nii.gz"),
        uncorrp_img=execution.output_file(output_root + "_uncorrp.nii.gz"),
        null_dist_file=execution.output_file(output_root + "_null_dist.txt"),
        glm_output_file=execution.output_file(output_root + "_glm.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SWE_METADATA",
    "SweOutputs",
    "swe",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMAGE_MATH_METADATA = Metadata(
    id="f5740d314a9baf77fb8fa3899fa5f569f4daee75.boutiques",
    name="ImageMath",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class ImageMathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `image_math(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """The resulting image after processing."""


def image_math(
    image_dimension: typing.Literal[2, 3, 4],
    output_image: InputPathType,
    operations_and_inputs: str,
    image1: InputPathType,
    image2: InputPathType | None = None,
    runner: Runner | None = None,
) -> ImageMathOutputs:
    """
    A versatile tool for performing various mathematical and manipulation operations
    on images.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the image. Use 2 or 3 for\
            spatial images, and 4 for 4D images like time-series data.
        output_image: The output image file resulting from the operations.
        operations_and_inputs: Mathematical operations and inputs to be applied\
            on the images.
        image1: The first input image for the operation.
        image2: The second input image for the operation, if required.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImageMathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMAGE_MATH_METADATA)
    cargs = []
    cargs.append("ImageMath")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(output_image))
    cargs.append(operations_and_inputs)
    cargs.append(execution.input_file(image1))
    if image2 is not None:
        cargs.append(execution.input_file(image2))
    ret = ImageMathOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(pathlib.Path(output_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMAGE_MATH_METADATA",
    "ImageMathOutputs",
    "image_math",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_OVERLAP_METADATA = Metadata(
    id="a1bc040d8dc7e5b89536a75a10ba6ad55a1ecc95.boutiques",
    name="3dOverlap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dOverlapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_overlap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_brik: OutputPathType
    """BRIK file with count of overlaps at each voxel (if -save is used)"""
    output_head: OutputPathType
    """HEAD file with count of overlaps at each voxel (if -save is used)"""


def v_3d_overlap(
    dataset1: InputPathType,
    dataset2: list[InputPathType],
    runner: Runner | None = None,
) -> V3dOverlapOutputs:
    """
    Counts the number of voxels that are nonzero in all input datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset1: First input dataset (e.g. dset1+orig).
        dataset2: Second input dataset (e.g. dset2+orig).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dOverlapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_OVERLAP_METADATA)
    cargs = []
    cargs.append("3dOverlap")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(dataset1))
    cargs.extend([execution.input_file(f) for f in dataset2])
    ret = V3dOverlapOutputs(
        root=execution.output_file("."),
        output_brik=execution.output_file("[SAVE_PREFIX]+orig.BRIK"),
        output_head=execution.output_file("[SAVE_PREFIX]+orig.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dOverlapOutputs",
    "V_3D_OVERLAP_METADATA",
    "v_3d_overlap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POST_RECON_ALL_METADATA = Metadata(
    id="043904c04e1a7c309fb6aa5cb7234831a996fdf4.boutiques",
    name="post-recon-all",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class PostReconAllOutputs(typing.NamedTuple):
    """
    Output object returned when calling `post_recon_all(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def post_recon_all(
    subject: str,
    no_subfields: bool = False,
    no_subregions: bool = False,
    no_cvs: bool = False,
    no_qcache: bool = False,
    no_sclimbic: bool = False,
    no_hthsu: bool = False,
    no_synthstrip: bool = False,
    no_synthseg: bool = False,
    no_qastats: bool = False,
    no_samseg: bool = False,
    no_xhemi: bool = False,
    no_cos7: bool = False,
    threads: float | None = None,
    force: bool = False,
    exit_on_error: bool = False,
    runner: Runner | None = None,
) -> PostReconAllOutputs:
    """
    Post-processing script typically run after recon-all in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier to be processed.
        no_subfields: Do not run subfields extraction.
        no_subregions: Do not run subregions extraction.
        no_cvs: Do not run CVS processing (default behavior).
        no_qcache: Do not run qcache processing.
        no_sclimbic: Do not run sclimbic processing.
        no_hthsu: Do not run hypothalamic subunits processing.
        no_synthstrip: Do not run synthstrip processing.
        no_synthseg: Do not run synthseg processing.
        no_qastats: Do not run qastats processing.
        no_samseg: Do not run samseg processing.
        no_xhemi: Do not run xhemi processing.
        no_cos7: Do not run commands from CentOS7 container.
        threads: Number of threads to be used.
        force: Force rerunning even if output is newer than input.
        exit_on_error: Exit immediately if an error occurs.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PostReconAllOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POST_RECON_ALL_METADATA)
    cargs = []
    cargs.extend([
        "-all",
        "post-recon" + subject
    ])
    if no_subfields:
        cargs.append("--no-subfields")
    if no_subregions:
        cargs.append("--no-subregions")
    if no_cvs:
        cargs.append("--no-cvs")
    if no_qcache:
        cargs.append("--no-qcache")
    if no_sclimbic:
        cargs.append("--no-sclimbic")
    if no_hthsu:
        cargs.append("--no-hthsu")
    if no_synthstrip:
        cargs.append("--no-synthstrip")
    if no_synthseg:
        cargs.append("--no-synthseg")
    if no_qastats:
        cargs.append("--no-qastats")
    if no_samseg:
        cargs.append("--no-samseg")
    if no_xhemi:
        cargs.append("--no-xhemi")
    if no_cos7:
        cargs.append("--no-cos7")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if force:
        cargs.append("--force")
    if exit_on_error:
        cargs.append("--exit-on-error")
    ret = PostReconAllOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POST_RECON_ALL_METADATA",
    "PostReconAllOutputs",
    "post_recon_all",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_RF_LONG_TRAIN_METADATA = Metadata(
    id="6aa2bd3c51dac0579c817b9ebcdd083599ca7cf8.boutiques",
    name="mri_rf_long_train",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriRfLongTrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_rf_long_train(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_rfa_file: OutputPathType
    """The output RFA file generated by the tool"""


def mri_rf_long_train(
    seg_dir: str,
    xform: str,
    subjects: list[str],
    output_rfa: str,
    mask: str | None = None,
    node_spacing: float | None = None,
    prior_spacing: float | None = None,
    input_data: list[str] | None = None,
    check: bool = False,
    runner: Runner | None = None,
) -> MriRfLongTrainOutputs:
    """
    Trains GCA data with multiple subjects for FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        seg_dir: Path to the segmentation volume directory, relative to\
            $subject/mri.
        xform: Atlas transform path relative to $subject/mri/transforms.
        subjects: List of subjects for training.
        output_rfa: Output RFA filename.
        mask: Volume name to use as a mask, path relative to $subject/mri.
        node_spacing: Spacing of classifiers in canonical space.
        prior_spacing: Spacing of class priors in canonical space.
        input_data: Specify training data, path relative to $subject/mri. Can\
            specify multiple inputs. Defaults to 'orig' if not specified.
        check: Conduct sanity-check of labels for obvious edit errors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriRfLongTrainOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_RF_LONG_TRAIN_METADATA)
    cargs = []
    cargs.append("mri_rf_long_train")
    cargs.extend([
        "-seg",
        seg_dir
    ])
    cargs.extend([
        "-xform",
        xform
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            mask
        ])
    if node_spacing is not None:
        cargs.extend([
            "-node_spacing",
            str(node_spacing)
        ])
    if prior_spacing is not None:
        cargs.extend([
            "-prior_spacing",
            str(prior_spacing)
        ])
    if input_data is not None:
        cargs.extend([
            "-input",
            *input_data
        ])
    if check:
        cargs.append("-check")
    cargs.extend(subjects)
    cargs.append(output_rfa)
    ret = MriRfLongTrainOutputs(
        root=execution.output_file("."),
        output_rfa_file=execution.output_file(output_rfa + ".rfa"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_RF_LONG_TRAIN_METADATA",
    "MriRfLongTrainOutputs",
    "mri_rf_long_train",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TKREGISTER2_CMDL_METADATA = Metadata(
    id="a084019981b8c19c88bf65a10695c9febf690ada.boutiques",
    name="tkregister2_cmdl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Tkregister2CmdlOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tkregister2_cmdl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tkregister2_cmdl(
    movable_volume: InputPathType,
    target_volume: InputPathType,
    fstarg_flag: bool = False,
    reg_file: InputPathType | None = None,
    check_reg_flag: bool = False,
    regheader_flag: bool = False,
    regheader_center_flag: bool = False,
    fsl_targ_flag: bool = False,
    fsl_targ_lr_flag: bool = False,
    gca_subject: str | None = None,
    gca_skull_subject: str | None = None,
    no_zero_cras_flag: bool = False,
    movbright: float | None = None,
    no_inorm_flag: bool = False,
    fmov: float | None = None,
    fmov_targ_flag: bool = False,
    plane: str | None = None,
    slice_: float | None = None,
    volview: str | None = None,
    fov: float | None = None,
    movscale: float | None = None,
    surf: str | None = None,
    surf_rgb: list[float] | None = None,
    lh_only_flag: bool = False,
    rh_only_flag: bool = False,
    fstal_flag: bool = False,
    talxfmname: str | None = None,
    ixfm: InputPathType | None = None,
    xfm: InputPathType | None = None,
    xfmout: InputPathType | None = None,
    fsl: InputPathType | None = None,
    fslregout: InputPathType | None = None,
    freeview: InputPathType | None = None,
    vox2vox: InputPathType | None = None,
    lta: InputPathType | None = None,
    lta_inv: InputPathType | None = None,
    ltaout: InputPathType | None = None,
    ltaout_inv_flag: bool = False,
    feat: str | None = None,
    fsfeat: str | None = None,
    identity_flag: bool = False,
    subject_id: str | None = None,
    subjects_dir: str | None = None,
    nofix_flag: bool = False,
    float2int: str | None = None,
    title: str | None = None,
    tag_flag: bool = False,
    mov_orientation: str | None = None,
    targ_orientation: str | None = None,
    int_: list[str] | None = None,
    double_window_size_flag: bool = False,
    window_scale: float | None = None,
    det: InputPathType | None = None,
    aseg_flag: bool = False,
    aparc_flag: bool = False,
    wmparc_flag: bool = False,
    gdiagno: float | None = None,
    trans: list[float] | None = None,
    rot: list[float] | None = None,
    conf_targ_flag: bool = False,
    runner: Runner | None = None,
) -> Tkregister2CmdlOutputs:
    """
    tkregister2 is a tool to assist in the manual tuning of the linear registration
    between two volumes, mainly for the purpose of interacting with the FreeSurfer
    anatomical stream.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        movable_volume: Path to the movable volume.
        target_volume: Path to the target volume.
        fstarg_flag: Target is relative to subjectid/mri.
        reg_file: Path to input/output registration file.
        check_reg_flag: Only check, no --reg needed.
        regheader_flag: Compute registration from headers.
        regheader_center_flag: Same as --regheader but aligns volume centers.
        fsl_targ_flag: Use FSLDIR/data/standard/avg152T1.nii.gz.
        fsl_targ_lr_flag: Use FSLDIR/data/standard/avg152T1_LR-marked.nii.gz.
        gca_subject: Subject ID for linear GCA registration check.
        gca_skull_subject: Subject ID for linear 'with skull' GCA registration\
            check.
        no_zero_cras_flag: Do not zero target cras (done with --fstal).
        movbright: Brightness of movable volume.
        no_inorm_flag: Turn off intensity normalization.
        fmov: Set movable volume brightness.
        fmov_targ_flag: Apply movable brightness to the target.
        plane: Startup view plane: cor, sag, ax.
        slice_: Startup slice number.
        volview: Startup with targ or mov.
        fov: Window FOV in mm (default is 256).
        movscale: Scale size of movable volume by scale.
        surf: Display surface as an overlay.
        surf_rgb: Set surface color (0-255) for R G B.
        lh_only_flag: Only load/display left hemisphere.
        rh_only_flag: Only load/display right hemisphere.
        fstal_flag: Set movable to be tal and reg to be taliarach.xfm.
        talxfmname: Set movable to be tal and reg to be talxfmname.
        ixfm: MNI-style inverse registration input matrix.
        xfm: MNI-style registration input matrix.
        xfmout: MNI-style registration output matrix.
        fsl: FSL-style registration input matrix.
        fslregout: FSL-Style registration output matrix.
        freeview: FreeView registration output matrix.
        vox2vox: Vox2vox matrix in ascii.
        lta: Linear Transform Array file.
        lta_inv: Read in LTA and invert.
        ltaout: Output a Linear Transform Array.
        ltaout_inv_flag: Invert transform in ltaoutfile.
        feat: Check example_func2standard registration.
        fsfeat: Check reg/freesurfer/register.dat registration.
        identity_flag: Use identity as registration matrix.
        subject_id: Set subject id.
        subjects_dir: Use specified directory as SUBJECTS_DIR.
        nofix_flag: Don't fix old tkregister matrices.
        float2int: Specify old tkregister float2int.
        title: Set window title.
        tag_flag: Tag movable volume near the col/row origin.
        mov_orientation: Supply orientation string for movable volume.
        targ_orientation: Supply orientation string for target volume.
        int_: Use registration from intermediate volume.
        double_window_size_flag: Double window size.
        window_scale: Scale window by specified scale.
        det: Save determinant of registration matrix to specified file.
        aseg_flag: Load aseg and hit 'd' to toggle.
        aparc_flag: Load aparc+aseg and hit 'c' to toggle.
        wmparc_flag: Load wmparc and hit 'c' to toggle.
        gdiagno: Set debug level.
        trans: Translation (mm) to apply to registration matrix.
        rot: Rotation angles (deg) to apply to registration matrix.
        conf_targ_flag: Conform target (assumes reg computed to conform target,\
            eg, GCA).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Tkregister2CmdlOutputs`).
    """
    if int_ is not None and (len(int_) != 2): 
        raise ValueError(f"Length of 'int_' must be 2 but was {len(int_)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(TKREGISTER2_CMDL_METADATA)
    cargs = []
    cargs.append("tkregister2_cmdl")
    cargs.extend([
        "--mov",
        execution.input_file(movable_volume)
    ])
    cargs.extend([
        "--targ",
        execution.input_file(target_volume)
    ])
    if fstarg_flag:
        cargs.append("--fstarg")
    if reg_file is not None:
        cargs.extend([
            "--reg",
            execution.input_file(reg_file)
        ])
    if check_reg_flag:
        cargs.append("--check-reg")
    if regheader_flag:
        cargs.append("--regheader")
    if regheader_center_flag:
        cargs.append("--regheader-center")
    if fsl_targ_flag:
        cargs.append("--fsl-targ")
    if fsl_targ_lr_flag:
        cargs.append("--fsl-targ-lr")
    if gca_subject is not None:
        cargs.extend([
            "--gca",
            gca_subject
        ])
    if gca_skull_subject is not None:
        cargs.extend([
            "--gca-skull",
            gca_skull_subject
        ])
    if no_zero_cras_flag:
        cargs.append("--no-zero-cras")
    if movbright is not None:
        cargs.extend([
            "--movbright",
            str(movbright)
        ])
    if no_inorm_flag:
        cargs.append("--no-inorm")
    if fmov is not None:
        cargs.extend([
            "--fmov",
            str(fmov)
        ])
    if fmov_targ_flag:
        cargs.append("--fmov-targ")
    if plane is not None:
        cargs.extend([
            "--plane",
            plane
        ])
    if slice_ is not None:
        cargs.extend([
            "--slice",
            str(slice_)
        ])
    if volview is not None:
        cargs.extend([
            "--volview",
            volview
        ])
    if fov is not None:
        cargs.extend([
            "--fov",
            str(fov)
        ])
    if movscale is not None:
        cargs.extend([
            "--movscale",
            str(movscale)
        ])
    if surf is not None:
        cargs.extend([
            "--surf",
            surf
        ])
    if surf_rgb is not None:
        cargs.extend([
            "--surf-rgb",
            *map(str, surf_rgb)
        ])
    if lh_only_flag:
        cargs.append("--lh-only")
    if rh_only_flag:
        cargs.append("--rh-only")
    if fstal_flag:
        cargs.append("--fstal")
    if talxfmname is not None:
        cargs.extend([
            "--talxfmname",
            talxfmname
        ])
    if ixfm is not None:
        cargs.extend([
            "--ixfm",
            execution.input_file(ixfm)
        ])
    if xfm is not None:
        cargs.extend([
            "--xfm",
            execution.input_file(xfm)
        ])
    if xfmout is not None:
        cargs.extend([
            "--xfmout",
            execution.input_file(xfmout)
        ])
    if fsl is not None:
        cargs.extend([
            "--fsl",
            execution.input_file(fsl)
        ])
    if fslregout is not None:
        cargs.extend([
            "--fslregout",
            execution.input_file(fslregout)
        ])
    if freeview is not None:
        cargs.extend([
            "--freeview",
            execution.input_file(freeview)
        ])
    if vox2vox is not None:
        cargs.extend([
            "--vox2vox",
            execution.input_file(vox2vox)
        ])
    if lta is not None:
        cargs.extend([
            "--lta",
            execution.input_file(lta)
        ])
    if lta_inv is not None:
        cargs.extend([
            "--lta-inv",
            execution.input_file(lta_inv)
        ])
    if ltaout is not None:
        cargs.extend([
            "--ltaout",
            execution.input_file(ltaout)
        ])
    if ltaout_inv_flag:
        cargs.append("--ltaout-inv")
    if feat is not None:
        cargs.extend([
            "--feat",
            feat
        ])
    if fsfeat is not None:
        cargs.extend([
            "--fsfeat",
            fsfeat
        ])
    if identity_flag:
        cargs.append("--identity")
    if subject_id is not None:
        cargs.extend([
            "--s",
            subject_id
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if nofix_flag:
        cargs.append("--nofix")
    if float2int is not None:
        cargs.extend([
            "--float2int",
            float2int
        ])
    if title is not None:
        cargs.extend([
            "--title",
            title
        ])
    if tag_flag:
        cargs.append("--tag")
    if mov_orientation is not None:
        cargs.extend([
            "--mov-orientation",
            mov_orientation
        ])
    if targ_orientation is not None:
        cargs.extend([
            "--targ-orientation",
            targ_orientation
        ])
    if int_ is not None:
        cargs.extend([
            "--int",
            *int_
        ])
    if double_window_size_flag:
        cargs.append("--2")
    if window_scale is not None:
        cargs.extend([
            "--size",
            str(window_scale)
        ])
    if det is not None:
        cargs.extend([
            "--det",
            execution.input_file(det)
        ])
    if aseg_flag:
        cargs.append("--aseg")
    if aparc_flag:
        cargs.append("--aparc+aseg")
    if wmparc_flag:
        cargs.append("--wmparc")
    if gdiagno is not None:
        cargs.extend([
            "--gdiagno",
            str(gdiagno)
        ])
    if trans is not None:
        cargs.extend([
            "--trans",
            *map(str, trans)
        ])
    if rot is not None:
        cargs.extend([
            "--rot",
            *map(str, rot)
        ])
    if conf_targ_flag:
        cargs.append("--conf-targ")
    ret = Tkregister2CmdlOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TKREGISTER2_CMDL_METADATA",
    "Tkregister2CmdlOutputs",
    "tkregister2_cmdl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LONG_SUBMIT_POSTPROC_METADATA = Metadata(
    id="f5d6d8fc46443ea959ac2b4347964b2a0edf8163.boutiques",
    name="long_submit_postproc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LongSubmitPostprocOutputs(typing.NamedTuple):
    """
    Output object returned when calling `long_submit_postproc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def long_submit_postproc(
    qdec: InputPathType,
    prog: str,
    flags: str | None = None,
    dir_: str | None = None,
    simulate: bool = False,
    pause: float | None = 13,
    max_: float | None = 100,
    queue_: str | None = None,
    runner: Runner | None = None,
) -> LongSubmitPostprocOutputs:
    """
    Submits jobs to the cluster (either seychelles or launchpad at NMR) for
    longitudinal post-processing.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        qdec: QDEC table file specifying the subjects and time points.
        prog: Longitudinal script to call.
        flags: Parameters (without --qdec) to pass to prog (using quotes ...).
        dir_: Directory to store sub-tables and command files.
        simulate: Do not submit anything, just print commands.
        pause: Pause in seconds between submissions.
        max_: Maximum number of jobs for this user.
        queue_: Special queue to submit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LongSubmitPostprocOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LONG_SUBMIT_POSTPROC_METADATA)
    cargs = []
    cargs.append("long_submit_postproc")
    cargs.extend([
        "--qdec",
        execution.input_file(qdec)
    ])
    cargs.extend([
        "--prog",
        prog
    ])
    if flags is not None:
        cargs.extend([
            "--flags",
            flags
        ])
    if dir_ is not None:
        cargs.extend([
            "--dir",
            dir_
        ])
    if simulate:
        cargs.append("--simulate")
    if pause is not None:
        cargs.extend([
            "--pause",
            str(pause)
        ])
    if max_ is not None:
        cargs.extend([
            "--max",
            str(max_)
        ])
    if queue_ is not None:
        cargs.extend([
            "--queue",
            queue_
        ])
    ret = LongSubmitPostprocOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LONG_SUBMIT_POSTPROC_METADATA",
    "LongSubmitPostprocOutputs",
    "long_submit_postproc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DTIGEN_METADATA = Metadata(
    id="1693c829ac7f8ececf6dc63605144e179c65163b.boutiques",
    name="dtigen",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class DtigenOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dtigen(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_diffusion_data: OutputPathType
    """Output diffusion data"""
    output_kurtosis_map: OutputPathType | None
    """Mean kurtosis map"""


def dtigen(
    tensor: InputPathType,
    s0: InputPathType,
    output_data: str,
    bvecs: InputPathType,
    bvals: InputPathType,
    brainmask: InputPathType,
    kurtosis: InputPathType | None = None,
    help_: bool = False,
    runner: Runner | None = None,
) -> DtigenOutputs:
    """
    Generate diffusion data using tensor model.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        tensor: Input tensor file.
        s0: Input S0 file.
        output_data: Output data file.
        bvecs: bvecs ASCII text file.
        bvals: bvals ASCII text file.
        brainmask: Brain mask file.
        kurtosis: Mean kurtosis map.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DtigenOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DTIGEN_METADATA)
    cargs = []
    cargs.append("dtigen")
    cargs.extend([
        "-t",
        execution.input_file(tensor)
    ])
    cargs.extend([
        "--s0",
        execution.input_file(s0)
    ])
    cargs.extend([
        "-o",
        output_data
    ])
    cargs.extend([
        "-r",
        execution.input_file(bvecs)
    ])
    cargs.extend([
        "-b",
        execution.input_file(bvals)
    ])
    cargs.extend([
        "-m",
        execution.input_file(brainmask)
    ])
    if kurtosis is not None:
        cargs.extend([
            "--kurt",
            execution.input_file(kurtosis)
        ])
    if help_:
        cargs.append("-h")
    ret = DtigenOutputs(
        root=execution.output_file("."),
        output_diffusion_data=execution.output_file(output_data + ".nii.gz"),
        output_kurtosis_map=execution.output_file(pathlib.Path(kurtosis).name) if (kurtosis is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DTIGEN_METADATA",
    "DtigenOutputs",
    "dtigen",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_LONG_NORMALIZE_METADATA = Metadata(
    id="50792d90ec13a1b27d5ecb59aea01240f09a6b39.boutiques",
    name="mri_long_normalize",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriLongNormalizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_long_normalize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output MRI volume file."""


def mri_long_normalize(
    input_vol: InputPathType,
    base_tp_file: InputPathType,
    output_vol: str,
    normalization_iters: int | None = None,
    disable_1d: bool = False,
    smooth_bias: float | None = None,
    aseg: InputPathType | None = None,
    debug_gvx: list[float] | None = None,
    debug_gx: list[float] | None = None,
    reading: list[str] | None = None,
    print_usage: bool = False,
    runner: Runner | None = None,
) -> MriLongNormalizeOutputs:
    """
    Tool to normalize the white-matter of MRI volumes, optionally based on control
    points.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_vol: Input MRI volume file.
        base_tp_file: Base time point file.
        output_vol: Output MRI volume file.
        normalization_iters: Use n 3D normalization iterations (default is 2).
        disable_1d: Disable 1D normalization.
        smooth_bias: Smooth the bias field.
        aseg: Aseg file specification.
        debug_gvx: For debugging: specify Gvx, Gvy, Gvz.
        debug_gx: For debugging: specify Gx, Gy, Gz.
        reading: For reading: specify control points and bias field.
        print_usage: Print usage information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriLongNormalizeOutputs`).
    """
    if reading is not None and (len(reading) != 2): 
        raise ValueError(f"Length of 'reading' must be 2 but was {len(reading)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_LONG_NORMALIZE_METADATA)
    cargs = []
    cargs.append("mri_long_normalize")
    cargs.append(execution.input_file(input_vol))
    cargs.append(execution.input_file(base_tp_file))
    cargs.append(output_vol)
    if normalization_iters is not None:
        cargs.extend([
            "-n",
            str(normalization_iters)
        ])
    if disable_1d:
        cargs.append("-no1d")
    if smooth_bias is not None:
        cargs.extend([
            "-sigma",
            str(smooth_bias)
        ])
    if aseg is not None:
        cargs.extend([
            "-a",
            execution.input_file(aseg)
        ])
    if debug_gvx is not None:
        cargs.extend([
            "-v",
            *map(str, debug_gvx)
        ])
    if debug_gx is not None:
        cargs.extend([
            "-d",
            *map(str, debug_gx)
        ])
    if reading is not None:
        cargs.extend([
            "-r",
            *reading
        ])
    if print_usage:
        cargs.append("-u")
    ret = MriLongNormalizeOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_vol),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_LONG_NORMALIZE_METADATA",
    "MriLongNormalizeOutputs",
    "mri_long_normalize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_ERRORS_METADATA = Metadata(
    id="ef9b47e313219e97d7f5d816c34ec14bc6f35660.boutiques",
    name="mris_errors",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisErrorsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_errors(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_errors(
    input_image_file: InputPathType,
    runner: Runner | None = None,
) -> MrisErrorsOutputs:
    """
    This program will unfold an MRI on the surface of an ellipsoid.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image_file: Input image file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisErrorsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_ERRORS_METADATA)
    cargs = []
    cargs.append("mris_errors")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_image_file))
    ret = MrisErrorsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_ERRORS_METADATA",
    "MrisErrorsOutputs",
    "mris_errors",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SEGMENT_HYPOTHALAMIC_SUBUNITS_METADATA = Metadata(
    id="f03ac3b7165171b1e5dc19884858113ebce6c791.boutiques",
    name="mri_segment_hypothalamic_subunits",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSegmentHypothalamicSubunitsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_segment_hypothalamic_subunits(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_output_files: OutputPathType | None
    """Segmentation output(s) in T1 mode."""
    posteriors_output: OutputPathType | None
    """Posteriors output(s)."""
    resampled_output: OutputPathType | None
    """Resampled image(s) output."""
    volume_output_csv: OutputPathType | None
    """CSV file with volumes for all structures and subjects."""


def mri_segment_hypothalamic_subunits(
    subjects: list[str] | None = None,
    subjects_dir: str | None = None,
    write_posteriors: bool = False,
    image_input: str | None = None,
    output: str | None = None,
    posteriors: str | None = None,
    resample: str | None = None,
    volume_output: str | None = None,
    crop_size: list[float] | None = None,
    threads: float | None = None,
    cpu: bool = False,
    runner: Runner | None = None,
) -> MriSegmentHypothalamicSubunitsOutputs:
    """
    This module segments hypothalamic subunits and can be run in two modes: on
    FreeSurfer subjects or on any T1-weighted scan(s) of approximately 1mm
    resolution.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: (required in FS mode) Name of one or several subjects in\
            $SUBJECTS_DIR on which to run the module, assuming recon-all has been\
            run on the specified subjects.
        subjects_dir: (FS mode, optional) Override current $SUBJECTS_DIR.
        write_posteriors: (FS mode, optional) Save posteriors; default is\
            False.
        image_input: (required in T1 mode) Image(s) to segment. Can be a path\
            to a single image or to a folder.
        output: (required in T1 mode) Segmentation output(s). Must be a folder\
            if --i designates a folder.
        posteriors: (T1 mode, optional) Posteriors output(s). Must be a folder\
            if --i designates a folder.
        resample: (T1 mode, optional) Resampled image(s). Must be a folder if\
            --i designates a folder.
        volume_output: (T1 mode, optional) Output CSV file with volumes for all\
            structures and subjects.
        crop_size: (both modes, optional) Size of the central patch to analyse\
            (must be divisible by 8). The whole image is analysed by default.
        threads: (both modes, optional) Number of cores to be used. Default\
            uses 1 core.
        cpu: (both modes, optional) Enforce running with CPU rather than GPU.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSegmentHypothalamicSubunitsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SEGMENT_HYPOTHALAMIC_SUBUNITS_METADATA)
    cargs = []
    cargs.append("mri_segment_hypothalamic_subunits")
    if subjects is not None:
        cargs.extend([
            "--s",
            *subjects
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if write_posteriors:
        cargs.append("--write_posteriors")
    if image_input is not None:
        cargs.extend([
            "--i",
            image_input
        ])
    if output is not None:
        cargs.extend([
            "--o",
            output
        ])
    if posteriors is not None:
        cargs.extend([
            "--post",
            posteriors
        ])
    if resample is not None:
        cargs.extend([
            "--resample",
            resample
        ])
    if volume_output is not None:
        cargs.extend([
            "--vol",
            volume_output
        ])
    if crop_size is not None:
        cargs.extend([
            "--crop",
            *map(str, crop_size)
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if cpu:
        cargs.append("--cpu")
    ret = MriSegmentHypothalamicSubunitsOutputs(
        root=execution.output_file("."),
        segmentation_output_files=execution.output_file(output) if (output is not None) else None,
        posteriors_output=execution.output_file(posteriors) if (posteriors is not None) else None,
        resampled_output=execution.output_file(resample) if (resample is not None) else None,
        volume_output_csv=execution.output_file(volume_output) if (volume_output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SEGMENT_HYPOTHALAMIC_SUBUNITS_METADATA",
    "MriSegmentHypothalamicSubunitsOutputs",
    "mri_segment_hypothalamic_subunits",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DJPEG_METADATA = Metadata(
    id="3600c030d01c581f3a3e8577bb83f497b31a9efb.boutiques",
    name="djpeg",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class DjpegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `djpeg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """Output image file"""


def djpeg(
    input_file: InputPathType,
    output_file: str,
    gray: bool = False,
    fast_dct: bool = False,
    one_pixel_height: bool = False,
    pseudo_pixel_ratio: bool = False,
    crop_region: str | None = None,
    runner: Runner | None = None,
) -> DjpegOutputs:
    """
    Decompress a JPEG file to an image file.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: Input JPEG file (e.g. image.jpg).
        output_file: Output image file (e.g. image.ppm).
        gray: Force grayscale output.
        fast_dct: Prevent dithering of output.
        one_pixel_height: Force one-pixel modulation flag.
        pseudo_pixel_ratio: Force pseudo-pixel ratio flag.
        crop_region: Crop region (syntax: WxH+X+Y, e.g., 100x100+10+10).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DjpegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DJPEG_METADATA)
    cargs = []
    cargs.append("djpeg")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    if gray:
        cargs.append("-grayscale")
    if fast_dct:
        cargs.append("-fast")
    if one_pixel_height:
        cargs.append("-onepixel")
    if pseudo_pixel_ratio:
        cargs.append("-236")
    if crop_region is not None:
        cargs.extend([
            "-crop",
            crop_region
        ])
    ret = DjpegOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DJPEG_METADATA",
    "DjpegOutputs",
    "djpeg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DMATCALC_METADATA = Metadata(
    id="363bd7932d82bc77c3f5fe6e0307d7efddad15de.boutiques",
    name="1dmatcalc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dmatcalcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dmatcalc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file resulting from the evaluated expression"""


def v_1dmatcalc(
    expression: str | None = None,
    runner: Runner | None = None,
) -> V1dmatcalcOutputs:
    """
    A tool to evaluate space-delimited RPN (Reverse Polish Notation) matrix-valued
    expressions.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        expression: Expression to evaluate the RPN matrix-valued operations.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dmatcalcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DMATCALC_METADATA)
    cargs = []
    cargs.append("1dmatcalc")
    if expression is not None:
        cargs.append(expression)
    ret = V1dmatcalcOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dmatcalcOutputs",
    "V_1DMATCALC_METADATA",
    "v_1dmatcalc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POPP_METADATA = Metadata(
    id="29bde353620add34cd7a90603c61465fa385c87a.boutiques",
    name="popp",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class PoppOutputs(typing.NamedTuple):
    """
    Output object returned when calling `popp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    processed_data_output: OutputPathType
    """Processed physiological data output"""
    timing_output: OutputPathType
    """Timing and triggers output"""
    rvt_data_output: OutputPathType
    """RVT data output file"""
    heartrate_data_output: OutputPathType
    """Heartrate data output file"""


def popp(
    input_file: InputPathType,
    output_basename: str,
    sampling_rate: float | None = 100,
    tr_value: float | None = None,
    resp_column: float | None = None,
    cardiac_column: float | None = None,
    trigger_column: float | None = None,
    rvt_flag: bool = False,
    heart_rate_flag: bool = False,
    pulseox_trigger_flag: bool = False,
    smooth_card: float | None = None,
    smooth_resp: float | None = None,
    high_freq_cutoff: float | None = 5,
    low_freq_cutoff: float | None = 0.1,
    init_thresh_c: float | None = 90,
    n_thresh_c: float | None = 60,
    init_thresh_r: float | None = 80,
    n_thresh_r: float | None = 80,
    invert_resp_flag: bool = False,
    invert_cardiac_flag: bool = False,
    noclean1_flag: bool = False,
    noclean2_flag: bool = False,
    load_card_phase: InputPathType | None = None,
    load_resp_phase: InputPathType | None = None,
    vol_file: InputPathType | None = None,
    start_sample: float | None = None,
    resp_add: str | None = None,
    resp_del: str | None = None,
    card_add: str | None = None,
    card_del: str | None = None,
    verbose_flag: bool = False,
    debug_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> PoppOutputs:
    """
    Physiological data processing tool of FSL.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: Input physiological data filename (text format).
        output_basename: Output basename for physiological data and\
            timing/triggers (no extensions).
        sampling_rate: Sampling rate in Hz (default is 100Hz).
        tr_value: TR value in seconds.
        resp_column: Specify column number of respiratory input.
        cardiac_column: Specify column number of cardiac input.
        trigger_column: Specify column number of trigger input.
        rvt_flag: Generate RVT data.
        heart_rate_flag: Generate heartrate data.
        pulseox_trigger_flag: Specify that cardiac data is a trigger.
        smooth_card: Specify smoothing amount for cardiac (in seconds).
        smooth_resp: Specify smoothing amount for respiratory (in seconds).
        high_freq_cutoff: High frequency cut off for respiratory filter in Hz\
            (default is 5Hz).
        low_freq_cutoff: Low frequency cut off for respiratory filter in Hz\
            (default is 0.1Hz).
        init_thresh_c: Initial threshold percentile for cardiac (default 90).
        n_thresh_c: Neighbourhood exclusion threshold percentile for cardiac\
            (default 60).
        init_thresh_r: Initial threshold percentile for respiratory (default\
            80).
        n_thresh_r: Neighbourhood exclusion threshold percentile for\
            respiratory (default 80).
        invert_resp_flag: Invert respiratory trace.
        invert_cardiac_flag: Invert cardiac trace.
        noclean1_flag: Turn off cleanup phase 1.
        noclean2_flag: Turn off cleanup phase 2.
        load_card_phase: Input cardiac phase for reprocessing (text format).
        load_resp_phase: Input respiratory phase for reprocessing (text format).
        vol_file: Input volumetric image (EPI) filename.
        start_sample: Set sample number of the starting time (t=0).
        resp_add: Comma separated list of times (in sec) to add to respiratory\
            peak list (uses nearest local max).
        resp_del: Comma separated list of times (in sec) to delete from\
            respiratory peak list (uses nearest existing peak).
        card_add: Comma separated list of times (in sec) to add to cardiac peak\
            list (uses nearest local max).
        card_del: Comma separated list of times (in sec) to delete from cardiac\
            peak list (uses nearest existing peak).
        verbose_flag: Switch on diagnostic messages.
        debug_flag: Output debugging information.
        help_flag: Display this help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PoppOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POPP_METADATA)
    cargs = []
    cargs.append("popp")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-o",
        output_basename
    ])
    if sampling_rate is not None:
        cargs.extend([
            "-s",
            str(sampling_rate)
        ])
    if tr_value is not None:
        cargs.extend([
            "--tr",
            str(tr_value)
        ])
    if resp_column is not None:
        cargs.extend([
            "--resp",
            str(resp_column)
        ])
    if cardiac_column is not None:
        cargs.extend([
            "--cardiac",
            str(cardiac_column)
        ])
    if trigger_column is not None:
        cargs.extend([
            "--trigger",
            str(trigger_column)
        ])
    if rvt_flag:
        cargs.append("--rvt")
    if heart_rate_flag:
        cargs.append("--heartrate")
    if pulseox_trigger_flag:
        cargs.append("--pulseox_trigger")
    if smooth_card is not None:
        cargs.extend([
            "--smoothcard",
            str(smooth_card)
        ])
    if smooth_resp is not None:
        cargs.extend([
            "--smoothresp",
            str(smooth_resp)
        ])
    if high_freq_cutoff is not None:
        cargs.extend([
            "--highfreqcutoff",
            str(high_freq_cutoff)
        ])
    if low_freq_cutoff is not None:
        cargs.extend([
            "--lowfreqcutoff",
            str(low_freq_cutoff)
        ])
    if init_thresh_c is not None:
        cargs.extend([
            "--initthreshc",
            str(init_thresh_c)
        ])
    if n_thresh_c is not None:
        cargs.extend([
            "--nthreshc",
            str(n_thresh_c)
        ])
    if init_thresh_r is not None:
        cargs.extend([
            "--initthreshr",
            str(init_thresh_r)
        ])
    if n_thresh_r is not None:
        cargs.extend([
            "--nthreshr",
            str(n_thresh_r)
        ])
    if invert_resp_flag:
        cargs.append("--invertresp")
    if invert_cardiac_flag:
        cargs.append("--invertcardiac")
    if noclean1_flag:
        cargs.append("--noclean1")
    if noclean2_flag:
        cargs.append("--noclean2")
    if load_card_phase is not None:
        cargs.extend([
            "--loadcardphase",
            execution.input_file(load_card_phase)
        ])
    if load_resp_phase is not None:
        cargs.extend([
            "--loadrespphase",
            execution.input_file(load_resp_phase)
        ])
    if vol_file is not None:
        cargs.extend([
            "--vol",
            execution.input_file(vol_file)
        ])
    if start_sample is not None:
        cargs.extend([
            "--startingsample",
            str(start_sample)
        ])
    if resp_add is not None:
        cargs.extend([
            "--respadd",
            resp_add
        ])
    if resp_del is not None:
        cargs.extend([
            "--respdel",
            resp_del
        ])
    if card_add is not None:
        cargs.extend([
            "--cardadd",
            card_add
        ])
    if card_del is not None:
        cargs.extend([
            "--carddel",
            card_del
        ])
    if verbose_flag:
        cargs.append("-v")
    if debug_flag:
        cargs.append("--debug")
    if help_flag:
        cargs.append("-h")
    ret = PoppOutputs(
        root=execution.output_file("."),
        processed_data_output=execution.output_file(output_basename + "_processed.txt"),
        timing_output=execution.output_file(output_basename + "_timing.txt"),
        rvt_data_output=execution.output_file(output_basename + "_rvt.txt"),
        heartrate_data_output=execution.output_file(output_basename + "_heartrate.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POPP_METADATA",
    "PoppOutputs",
    "popp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_GCAB_TRAIN_METADATA = Metadata(
    id="5b3336956c10bad5fe64ad5c8c726b6429d9bf74.boutiques",
    name="mri_gcab_train",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriGcabTrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_gcab_train(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_gcab_train(
    runner: Runner | None = None,
) -> MriGcabTrainOutputs:
    """
    Previously used command in FreeSurfer for training with Gaussian Classifier
    Atlas-based (GCAB) modeling; has been removed in the current version.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriGcabTrainOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_GCAB_TRAIN_METADATA)
    cargs = []
    cargs.append("mri_gcab_train")
    ret = MriGcabTrainOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_GCAB_TRAIN_METADATA",
    "MriGcabTrainOutputs",
    "mri_gcab_train",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DROTATE_METADATA = Metadata(
    id="dae9478b93184d9121e61e24d56f3c564e520ade.boutiques",
    name="3drotate",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3drotateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3drotate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_head: OutputPathType | None
    """Output dataset header file"""
    out_brick: OutputPathType | None
    """Output dataset brick file"""


def v_3drotate(
    dataset: InputPathType,
    prefix: str | None = None,
    verbose: bool = False,
    ashift: list[float] | None = None,
    bshift: list[float] | None = None,
    rotate: list[str] | None = None,
    rotparent: InputPathType | None = None,
    gridparent: InputPathType | None = None,
    matvec_dicom: InputPathType | None = None,
    matvec_order: InputPathType | None = None,
    matvec_dset: InputPathType | None = None,
    dfile: InputPathType | None = None,
    v_1_dfile: InputPathType | None = None,
    points: bool = False,
    origin: list[float] | None = None,
    fourier: bool = False,
    nn: bool = False,
    linear: bool = False,
    cubic: bool = False,
    quintic: bool = False,
    heptic: bool = False,
    fourier_nopad: bool = False,
    clipit: bool = False,
    noclip: bool = False,
    zpad: float | None = None,
    runner: Runner | None = None,
) -> V3drotateOutputs:
    """
    Rotates and/or translates all bricks from an AFNI dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Input AFNI dataset, may contain a sub-brick selector list.
        prefix: Sets the output dataset prefix name.
        verbose: Prints out progress reports (to stderr).
        ashift: Shifts the dataset by specified distances (dx, dy, dz) in mm in\
            x, y, z directions respectively, AFTER rotation.
        bshift: Shifts the dataset by specified distances (dx, dy, dz) in mm in\
            x, y, z directions respectively, BEFORE rotation.
        rotate: Specifies the 3D rotation angles (th1, th2, th3) about certain\
            axes.
        rotparent: Rotation and translation should be taken from the first\
            3dvolreg transformation found in the header of dataset 'rset'.
        gridparent: Output dataset should be shifted to match the grid of\
            dataset 'gset'. Can only be used with -rotparent.
        matvec_dicom: Rotation and translation should be read from DICOM file\
            'mfile'.
        matvec_order: Rotation and translation should be read from file 'mfile'\
            with dataset coordinate order.
        matvec_dset: Rotation and translation should be read from the .HEAD\
            file of dataset 'mset' created by 3dTagalign.
        dfile: Reads movement parameters for each sub-brick from an ASCII file\
            'dname'.
        v_1_dfile: Reads movement parameters for each sub-brick from a 1D ASCII\
            file 'dname'.
        points: Specifies that (x,y,z) points are to be rotated instead of a\
            dataset.
        origin: Specifies the rotation origin point (xo, yo, zo).
        fourier: Use Fourier interpolation method during transformation.
        nn: Use nearest neighbor interpolation method during transformation.
        linear: Use linear interpolation (1st order polynomial) during\
            transformation.
        cubic: Use cubic interpolation (3rd order polynomial) during\
            transformation.
        quintic: Use quintic interpolation (5th order Lagrange polynomial)\
            during transformation.
        heptic: Use heptic interpolation (7th order Lagrange polynomial) during\
            transformation.
        fourier_nopad: Use the Fourier method WITHOUT padding.
        clipit: Clip results to input brick range [default option].
        noclip: Do not clip results to input brick range.
        zpad: Zero pad around the edges by 'n' voxels during rotations.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3drotateOutputs`).
    """
    if rotate is not None and (len(rotate) != 3): 
        raise ValueError(f"Length of 'rotate' must be 3 but was {len(rotate)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DROTATE_METADATA)
    cargs = []
    cargs.append("3drotate")
    cargs.append(execution.input_file(dataset))
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if verbose:
        cargs.append("-verbose")
    if ashift is not None:
        cargs.extend([
            "-ashift",
            *map(str, ashift)
        ])
    if bshift is not None:
        cargs.extend([
            "-bshift",
            *map(str, bshift)
        ])
    if rotate is not None:
        cargs.extend([
            "-rotate",
            *rotate
        ])
    if rotparent is not None:
        cargs.extend([
            "-rotparent",
            execution.input_file(rotparent)
        ])
    if gridparent is not None:
        cargs.extend([
            "-gridparent",
            execution.input_file(gridparent)
        ])
    if matvec_dicom is not None:
        cargs.extend([
            "-matvec_dicom",
            execution.input_file(matvec_dicom)
        ])
    if matvec_order is not None:
        cargs.extend([
            "-matvec_order",
            execution.input_file(matvec_order)
        ])
    if matvec_dset is not None:
        cargs.extend([
            "-matvec_dset",
            execution.input_file(matvec_dset)
        ])
    if dfile is not None:
        cargs.extend([
            "-dfile",
            execution.input_file(dfile)
        ])
    if v_1_dfile is not None:
        cargs.extend([
            "-1Dfile",
            execution.input_file(v_1_dfile)
        ])
    if points:
        cargs.append("-points")
    if origin is not None:
        cargs.extend([
            "-origin",
            *map(str, origin)
        ])
    if fourier:
        cargs.append("-Fourier")
    if nn:
        cargs.append("-NN")
    if linear:
        cargs.append("-linear")
    if cubic:
        cargs.append("-cubic")
    if quintic:
        cargs.append("-quintic")
    if heptic:
        cargs.append("-heptic")
    if fourier_nopad:
        cargs.append("-Fourier_nopad")
    if clipit:
        cargs.append("-clipit")
    if noclip:
        cargs.append("-noclip")
    if zpad is not None:
        cargs.extend([
            "-zpad",
            str(zpad)
        ])
    ret = V3drotateOutputs(
        root=execution.output_file("."),
        out_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
        out_brick=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3drotateOutputs",
    "V_3DROTATE_METADATA",
    "v_3drotate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_EXCHANGE_METADATA = Metadata(
    id="5e04c8d2b1860f0ec51964e8b982b73eaddf8469.boutiques",
    name="3dExchange",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dExchangeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_exchange(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_head: OutputPathType
    """Output HEAD file"""
    output_brik: OutputPathType
    """Output BRIK file"""


def v_3d_exchange(
    prefix: str,
    infile: InputPathType,
    mapfile: InputPathType,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> V3dExchangeOutputs:
    """
    Replaces voxel values using a mapping file with specified columns.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Output prefix.
        infile: Input dataset. Acceptable data types are byte, short, and\
            floats.
        mapfile: Mapping columns. Input values in the first column, output\
            values in the second column.
        version: Print author and version info.
        help_: Print this help screen.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dExchangeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_EXCHANGE_METADATA)
    cargs = []
    cargs.append("3dExchange")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-input",
        execution.input_file(infile)
    ])
    cargs.extend([
        "-map",
        execution.input_file(mapfile)
    ])
    if version:
        cargs.append("-ver")
    if help_:
        cargs.append("-help")
    ret = V3dExchangeOutputs(
        root=execution.output_file("."),
        output_head=execution.output_file(prefix + "+orig.HEAD"),
        output_brik=execution.output_file(prefix + "+orig.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dExchangeOutputs",
    "V_3D_EXCHANGE_METADATA",
    "v_3d_exchange",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_TABLES_LH_METADATA = Metadata(
    id="e50487cf18790588cbef4e2983a79d88589f3cc3.boutiques",
    name="morph_tables-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphTablesLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_tables_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output results from morphological analysis (example, adjust as needed)"""


def morph_tables_lh(
    input_file: InputPathType,
    some_flag: bool = False,
    runner: Runner | None = None,
) -> MorphTablesLhOutputs:
    """
    Morphological analysis tool for left hemisphere in Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file for morphological analysis.
        some_flag: Example flag (replace with actual options from tool if\
            known).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphTablesLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_TABLES_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "morph_tables" + execution.input_file(input_file)
    ])
    if some_flag:
        cargs.append("--some-flag")
    ret = MorphTablesLhOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(input_file).name + "_output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_TABLES_LH_METADATA",
    "MorphTablesLhOutputs",
    "morph_tables_lh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GCAPREPONE_METADATA = Metadata(
    id="2e14a31362a677b265992815008f70a18a14c39c.boutiques",
    name="gcaprepone",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GcapreponeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gcaprepone(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def gcaprepone(
    gcadir: str,
    subject: str,
    source_subjects_dir: str,
    done_file: str,
    init_subject: bool = False,
    no_emreg: bool = False,
    runner: Runner | None = None,
) -> GcapreponeOutputs:
    """
    Tool for preparing FreeSurfer subjects for use with group-wise template
    generation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        gcadir: Directory to be the new SUBJECTS_DIR.
        subject: Subject for the process.
        source_subjects_dir: SUBJECTS_DIR for source data.
        done_file: File to indicate completion.
        init_subject: Flag indicating the initial subject.
        no_emreg: Flag to skip EM registration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GcapreponeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GCAPREPONE_METADATA)
    cargs = []
    cargs.append("gcaprepone")
    cargs.extend([
        "--o",
        gcadir
    ])
    cargs.extend([
        "--s",
        subject
    ])
    if init_subject:
        cargs.append("--init-subject")
    cargs.extend([
        "--sd",
        source_subjects_dir
    ])
    cargs.extend([
        "--done",
        done_file
    ])
    if no_emreg:
        cargs.append("--no-emreg")
    ret = GcapreponeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GCAPREPONE_METADATA",
    "GcapreponeOutputs",
    "gcaprepone",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APARC2FEAT_METADATA = Metadata(
    id="40a686bfd13826d8c5472e46b643ff5ee20464a4.boutiques",
    name="aparc2feat",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Aparc2featOutputs(typing.NamedTuple):
    """
    Output object returned when calling `aparc2feat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    lh_aparc_output: OutputPathType
    """Output Left Hemisphere aparc in nifti format."""
    rh_aparc_output: OutputPathType
    """Output Right Hemisphere aparc in nifti format."""


def aparc2feat(
    feat_directories: str,
    featdirfile: InputPathType | None = None,
    hemi: str | None = None,
    annot: str | None = None,
    annot_a2005s_flag: bool = False,
    annot_a2009s_flag: bool = False,
    debug_flag: bool = False,
    runner: Runner | None = None,
) -> Aparc2featOutputs:
    """
    Resamples the FreeSurfer automatic cortical segmentation to the FEAT functional
    space.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        feat_directories: FEAT output directory. Multiple --feat arguments can\
            be supplied.
        featdirfile: File with a list of FEAT directories. Multiple\
            --featdirfile flags are allowed.
        hemi: Resample hemisphere only (default is both rh and lh).
        annot: Specify something other than aparc.
        annot_a2005s_flag: Specify annotation = aparc.a2005s.
        annot_a2009s_flag: Specify annotation = aparc.a2009s.
        debug_flag: Turn on debugging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Aparc2featOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APARC2FEAT_METADATA)
    cargs = []
    cargs.append("aparc2feat")
    cargs.extend([
        "--feat",
        feat_directories
    ])
    if featdirfile is not None:
        cargs.extend([
            "--featdirfile",
            execution.input_file(featdirfile)
        ])
    if hemi is not None:
        cargs.extend([
            "--hemi",
            hemi
        ])
    if annot is not None:
        cargs.extend([
            "--annot",
            annot
        ])
    if annot_a2005s_flag:
        cargs.append("--a2005s")
    if annot_a2009s_flag:
        cargs.append("--a2009s")
    if debug_flag:
        cargs.append("--debug")
    ret = Aparc2featOutputs(
        root=execution.output_file("."),
        lh_aparc_output=execution.output_file(feat_directories + "/reg/freesurfer/lh.aparc.nii.gz"),
        rh_aparc_output=execution.output_file(feat_directories + "/reg/freesurfer/rh.aparc.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APARC2FEAT_METADATA",
    "Aparc2featOutputs",
    "aparc2feat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PASTE_IMAGE_INTO_IMAGE_METADATA = Metadata(
    id="473380596b87ce0da9928dabd1961225e23dd0a4.boutiques",
    name="PasteImageIntoImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class PasteImageIntoImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `paste_image_into_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType
    """The final output image with the input image pasted onto the canvas."""


def paste_image_into_image(
    image_dimension: int,
    input_canvas_image: InputPathType,
    input_image: InputPathType,
    output_image: InputPathType,
    start_index: str,
    background_label: int | None = 0,
    paint_over_non_background_voxels: typing.Literal[0, 1, 2] | None = 0,
    conflict_label: int | None = -1,
    runner: Runner | None = None,
) -> PasteImageIntoImageOutputs:
    """
    Paste the input image into the input canvas image. Depending on parameters, it
    can replace or merge existing voxel values.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Specify the dimension of the images.
        input_canvas_image: The canvas image on which the input image will be\
            pasted.
        input_image: The image to be pasted onto the canvas.
        output_image: The resulting image after pasting.
        start_index: The starting index where the input image will be pasted on\
            the canvas.
        background_label: The label value considered as background.
        paint_over_non_background_voxels: Defines behavior when the input image\
            voxel is non-background and the corresponding canvas voxel is\
            background: 0 - leave as is, 1 - replace with input voxel value, 2 -\
            replace with conflict label.
        conflict_label: The label value used for conflicting non-background\
            voxels if 'paintOverNonBackgroundVoxels' is set to 2.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PasteImageIntoImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PASTE_IMAGE_INTO_IMAGE_METADATA)
    cargs = []
    cargs.append("PasteImageIntoImage")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(input_canvas_image))
    cargs.append(execution.input_file(input_image))
    cargs.append(execution.input_file(output_image))
    cargs.append(start_index)
    if background_label is not None:
        cargs.append(str(background_label))
    if paint_over_non_background_voxels is not None:
        cargs.append(str(paint_over_non_background_voxels))
    if conflict_label is not None:
        cargs.append(str(conflict_label))
    ret = PasteImageIntoImageOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(pathlib.Path(output_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PASTE_IMAGE_INTO_IMAGE_METADATA",
    "PasteImageIntoImageOutputs",
    "paste_image_into_image",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ROI_DECLUSTER_METADATA = Metadata(
    id="c565e19b7f5a74c17db9a508d6eb500dd6dc0e98.boutiques",
    name="@ROI_decluster",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VRoiDeclusterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__roi_decluster(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Final output dataset"""


def v__roi_decluster(
    input_dset: InputPathType,
    output_dir: str | None = None,
    nvox_thresh: float | None = None,
    frac_thresh: float | None = None,
    prefix: str | None = None,
    neighborhood_type: int | None = None,
    runner: Runner | None = None,
) -> VRoiDeclusterOutputs:
    """
    Script to remove small clusters or standalone voxels from an ROI/atlas dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dset: Required input dataset. This dataset should be set of\
            integer values. The program mostly assumes approximate isotropic\
            voxels.
        output_dir: Directory name for output. All output goes to this\
            directory.
        nvox_thresh: Number of voxels in a cluster to keep.
        frac_thresh: Fraction of voxels in a cluster to keep [0.0-1.0].
        prefix: Base name of final output dataset, i.e. baseprefix.nii.gz.
        neighborhood_type: Neighborhood type using in finding mode: 1 - facing\
            neighbors, 2 - edges, 3 - corners.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VRoiDeclusterOutputs`).
    """
    if neighborhood_type is not None and not (1 <= neighborhood_type <= 3): 
        raise ValueError(f"'neighborhood_type' must be between 1 <= x <= 3 but was {neighborhood_type}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ROI_DECLUSTER_METADATA)
    cargs = []
    cargs.append("@ROI_decluster")
    cargs.extend([
        "-input",
        execution.input_file(input_dset)
    ])
    if output_dir is not None:
        cargs.extend([
            "-outdir",
            output_dir
        ])
    if nvox_thresh is not None:
        cargs.extend([
            "-nvox_thresh",
            str(nvox_thresh)
        ])
    if frac_thresh is not None:
        cargs.extend([
            "-frac_thresh",
            str(frac_thresh)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if neighborhood_type is not None:
        cargs.extend([
            "-NN",
            str(neighborhood_type)
        ])
    ret = VRoiDeclusterOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VRoiDeclusterOutputs",
    "V__ROI_DECLUSTER_METADATA",
    "v__roi_decluster",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APARCSTATSDIFF_METADATA = Metadata(
    id="c9cea4353f4e4aca9c0c94b627fe528484a4d224.boutiques",
    name="aparcstatsdiff",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class AparcstatsdiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `aparcstatsdiff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output table with percentage differences"""


def aparcstatsdiff(
    subj1: str,
    subj2: str,
    hemi: str,
    parc: str,
    meas: str,
    outdir: str | None = None,
    runner: Runner | None = None,
) -> AparcstatsdiffOutputs:
    """
    Utility to calculate percentage differences in aparc morphometry data between
    two subjects.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subj1: Subject 1 identifier.
        subj2: Subject 2 identifier.
        hemi: Hemisphere (rh or lh).
        parc: Parcellation scheme (aparc or aparc.a2009s).
        meas: Measure type (area, volume, or thickness).
        outdir: Directory to write the output table file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AparcstatsdiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APARCSTATSDIFF_METADATA)
    cargs = []
    cargs.append("aparcstatsdiff")
    cargs.append(subj1)
    cargs.append(subj2)
    cargs.append(hemi)
    cargs.append(parc)
    cargs.append(meas)
    if outdir is not None:
        cargs.append(outdir)
    ret = AparcstatsdiffOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("aparcstats-" + hemi + "." + parc + "." + meas + ".txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APARCSTATSDIFF_METADATA",
    "AparcstatsdiffOutputs",
    "aparcstatsdiff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_SLICE_REGULARIZED_REGISTRATION_METADATA = Metadata(
    id="f5c4948fa2560385a828a453a54af7e3a4ab4be7.boutiques",
    name="antsSliceRegularizedRegistration",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsSliceRegularizedRegistrationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_slice_regularized_registration(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    polynomial_fit: OutputPathType
    """Output is the polynomial fit to Tx & Ty."""
    transformed_image: OutputPathType
    """Output is the transformed image."""


def ants_slice_regularized_registration(
    polydegree: int,
    output: str,
    metric: str,
    transform: str,
    iterations: str,
    shrink_factors: str,
    smoothing_sigmas: str,
    mask: InputPathType | None = None,
    interpolation: typing.Literal["Linear", "NearestNeighbor", "MultiLabel", "Gaussian", "BSpline", "CosineWindowedSinc", "WelchWindowedSinc", "HammingWindowedSinc", "LanczosWindowedSinc", "GenericLabel"] | None = None,
    verbose: typing.Literal[0] | None = None,
    runner: Runner | None = None,
) -> AntsSliceRegularizedRegistrationOutputs:
    """
    This program is a user-level application for slice-by-slice translation
    registration. Results are regularized in z using polynomial regression. The
    program is targeted at spinal cord MRI. Only one stage is supported where a
    stage consists of a transform; an image metric; and iterations, shrink factors,
    and smoothing sigmas for each level. Specialized for 3D data: fixed image is 3D,
    moving image is 3D. Registration is performed slice-by-slice then regularized in
    z. The parameter -p controls the polynomial degree. -p 0 means no
    regularization.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        polydegree: Degree of polynomial up to zDimension-2. Controls the\
            polynomial degree. 0 means no regularization.
        output: Specify the output transform prefix (output format is .nii.gz).\
            Optionally, one can choose to warp the moving image to the fixed space,\
            and if the inverse transform exists, one can also output the warped\
            fixed image.
        metric: Four image metrics are available: GC: global correlation, CC:\
            ANTS neighborhood cross correlation, MI: Mutual information, and\
            MeanSquares: mean-squares intensity difference.
        transform: Several transform options are available. The gradientStep or\
            learningRate characterizes the gradient descent optimization.
        iterations: Specify the number of iterations at each level.
        shrink_factors: Specify the shrink factor for the virtual domain\
            (typically the fixed image) at each level.
        smoothing_sigmas: Specify the amount of smoothing at each level.
        mask: Fixed image mask to limit voxels considered by the metric.
        interpolation: Several interpolation options are available in ITK.
        verbose: Verbose option.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsSliceRegularizedRegistrationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_SLICE_REGULARIZED_REGISTRATION_METADATA)
    cargs = []
    cargs.append("antsSliceRegularizedRegistration")
    cargs.extend([
        "-p",
        str(polydegree)
    ])
    cargs.extend([
        "-o",
        output
    ])
    cargs.extend([
        "-m",
        metric
    ])
    cargs.extend([
        "-t",
        transform
    ])
    cargs.extend([
        "-i",
        iterations
    ])
    cargs.extend([
        "-f",
        shrink_factors
    ])
    cargs.extend([
        "-s",
        smoothing_sigmas
    ])
    if mask is not None:
        cargs.extend([
            "-x",
            execution.input_file(mask)
        ])
    if interpolation is not None:
        cargs.extend([
            "-n",
            interpolation
        ])
    if verbose is not None:
        cargs.extend([
            "-v",
            str(verbose)
        ])
    ret = AntsSliceRegularizedRegistrationOutputs(
        root=execution.output_file("."),
        polynomial_fit=execution.output_file("[OUTPUT_PREFIX]TxTy_poly.csv"),
        transformed_image=execution.output_file("[OUTPUT_PREFIX].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_SLICE_REGULARIZED_REGISTRATION_METADATA",
    "AntsSliceRegularizedRegistrationOutputs",
    "ants_slice_regularized_registration",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LONG_STATS_TPS_METADATA = Metadata(
    id="bc2f340c25927fb0b4a967b198182aa268f9cf9f.boutiques",
    name="long_stats_tps",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LongStatsTpsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `long_stats_tps(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stacked_results: OutputPathType
    """File containing stacked results for individual time points."""


def long_stats_tps(
    qdec_table: InputPathType,
    stats_file: str,
    measure: str,
    subjects_dir: str,
    time_point: float,
    output_file: str,
    qcolumn: str | None = None,
    cross_sectional: bool = False,
    runner: Runner | None = None,
) -> LongStatsTpsOutputs:
    """
    Stack results for individual time points based on longitudinal qdec table.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        qdec_table: qdec.table.dat file with first columns: fsid fsid-base.
        stats_file: Stats file without path: e.g. aseg.stats or lh.aparc.stats.
        measure: Stats measure, e.g. volume, thickness, mean, std.
        subjects_dir: Full path to FreeSurfer subjects directory.
        time_point: Time point number.
        output_file: File name of output.
        qcolumn: Select a column from the qdec table itself (then --stats,\
            --meas and --sd are not necessary).
        cross_sectional: Use cross sectional results (for testing only).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LongStatsTpsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LONG_STATS_TPS_METADATA)
    cargs = []
    cargs.append("long_stats_tps")
    cargs.extend([
        "--qdec",
        "--qdec=" + execution.input_file(qdec_table)
    ])
    cargs.extend([
        "--stats",
        "--stats=" + stats_file
    ])
    cargs.extend([
        "--meas",
        "--meas=" + measure
    ])
    cargs.extend([
        "--sd",
        "--sd=" + subjects_dir
    ])
    cargs.extend([
        "--tp",
        "--tp=" + str(time_point)
    ])
    cargs.extend([
        "--out",
        "--out=" + output_file
    ])
    if qcolumn is not None:
        cargs.extend([
            "--qcol",
            qcolumn
        ])
    if cross_sectional:
        cargs.append("--cross")
    ret = LongStatsTpsOutputs(
        root=execution.output_file("."),
        stacked_results=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LONG_STATS_TPS_METADATA",
    "LongStatsTpsOutputs",
    "long_stats_tps",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_ONLY_SUBJECT_METADATA = Metadata(
    id="bff2c0f8f21164dcde88d76e1c6a7e662e454b4a.boutiques",
    name="morph_only_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphOnlySubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_only_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_only_subject(
    placeholder_input: str | None = None,
    runner: Runner | None = None,
) -> MorphOnlySubjectOutputs:
    """
    A placeholder descriptor for morph_only_subject tool as help content is
    unavailable.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        placeholder_input: Placeholder input argument for morph_only_subject\
            tool.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphOnlySubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_ONLY_SUBJECT_METADATA)
    cargs = []
    cargs.append("morph_only_subject")
    if placeholder_input is not None:
        cargs.append(placeholder_input)
    ret = MorphOnlySubjectOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_ONLY_SUBJECT_METADATA",
    "MorphOnlySubjectOutputs",
    "morph_only_subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_FDR_METADATA = Metadata(
    id="94b53ea7d88621220b891d96dc62c9924e143dac.boutiques",
    name="surface_fdr",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SurfaceFdrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_fdr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    pvals_vtk: OutputPathType
    """Output VTK file with corrected p-values"""
    fthresh_vtk: OutputPathType
    """Output VTK file with FDR thresholded values"""
    nifti_images: OutputPathType
    """Additional output NIFTI images"""


def surface_fdr(
    input_vtk: InputPathType,
    runner: Runner | None = None,
) -> SurfaceFdrOutputs:
    """
    Tool to calculate surface FDR correction for vertex analysis.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_vtk: Input VTK file from vertex analysis.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceFdrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_FDR_METADATA)
    cargs = []
    cargs.append("surface_fdr")
    cargs.append(execution.input_file(input_vtk))
    ret = SurfaceFdrOutputs(
        root=execution.output_file("."),
        pvals_vtk=execution.output_file(pathlib.Path(input_vtk).name + "_pvals.vtk"),
        fthresh_vtk=execution.output_file(pathlib.Path(input_vtk).name + "_Fthresh.vtk"),
        nifti_images=execution.output_file(pathlib.Path(input_vtk).name + "_*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_FDR_METADATA",
    "SurfaceFdrOutputs",
    "surface_fdr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_DISTANCE_MAP_METADATA = Metadata(
    id="3d8e889c4b656344736f94614b767e1d77d78242.boutiques",
    name="mris_distance_map",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisDistanceMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_distance_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output scalar field file"""


def mris_distance_map(
    input_surface_file: InputPathType,
    output_scalar_field: str,
    runner: Runner | None = None,
) -> MrisDistanceMapOutputs:
    """
    Tool to compute a distance map of each point on the surface to a reference
    point.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface_file: Input surface file.
        output_scalar_field: Output scalar field (.mgz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisDistanceMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_DISTANCE_MAP_METADATA)
    cargs = []
    cargs.append("mris_distance_map")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_surface_file))
    cargs.append(output_scalar_field)
    ret = MrisDistanceMapOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_scalar_field + ".mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_DISTANCE_MAP_METADATA",
    "MrisDistanceMapOutputs",
    "mris_distance_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

READ_MATLAB_FILES_PY_METADATA = Metadata(
    id="228461aad9e4f1abdf8c4f6cdf4dda42da06fc96.boutiques",
    name="read_matlab_files.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ReadMatlabFilesPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `read_matlab_files_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    converted_1d_file: OutputPathType | None
    """Converted 1D format file"""


def read_matlab_files_py(
    infiles: list[str],
    prefix: str | None = None,
    overwrite: bool = False,
    help_: bool = False,
    history: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> ReadMatlabFilesPyOutputs:
    """
    Describe or convert MATLAB files (.mat) to 1D format.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infiles: Input MATLAB files to be processed.
        prefix: Prefix for output file names.
        overwrite: Overwrite any existing output files.
        help_: Show help message.
        history: Show revision history.
        version: Show version number.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ReadMatlabFilesPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(READ_MATLAB_FILES_PY_METADATA)
    cargs = []
    cargs.append("read_matlab_files.py")
    cargs.extend(infiles)
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if overwrite:
        cargs.append("-overwrite")
    if help_:
        cargs.append("-help")
    if history:
        cargs.append("-hist")
    if version:
        cargs.append("-ver")
    ret = ReadMatlabFilesPyOutputs(
        root=execution.output_file("."),
        converted_1d_file=execution.output_file(prefix + ".[INDEX].[KEY].1D") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "READ_MATLAB_FILES_PY_METADATA",
    "ReadMatlabFilesPyOutputs",
    "read_matlab_files_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RECON_ALL_EXVIVO_METADATA = Metadata(
    id="ab8a5243b725eb3269bc328c28f826e76302edba.boutiques",
    name="recon-all-exvivo",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ReconAllExvivoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `recon_all_exvivo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def recon_all_exvivo(
    subject_id: str,
    hemisphere: str | None = None,
    nocerebellum: bool = False,
    runner: Runner | None = None,
) -> ReconAllExvivoOutputs:
    """
    A script to perform an ex vivo reconstruction with FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject identifier.
        hemisphere: Specify hemisphere: -lh for left, -rh for right hemisphere.
        nocerebellum: Do not process cerebellum.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ReconAllExvivoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RECON_ALL_EXVIVO_METADATA)
    cargs = []
    cargs.append("recon-all-exvivo")
    cargs.extend([
        "-s",
        subject_id
    ])
    if hemisphere is not None:
        cargs.extend([
            "-[lr]h",
            hemisphere
        ])
    if nocerebellum:
        cargs.append("-nocerebellum")
    ret = ReconAllExvivoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RECON_ALL_EXVIVO_METADATA",
    "ReconAllExvivoOutputs",
    "recon_all_exvivo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_VOLDIFF_METADATA = Metadata(
    id="049ba42a8da17fa9e060b046adb2f02031ce75c5.boutiques",
    name="mri_voldiff",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriVoldiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_voldiff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_voldiff(
    volume1: InputPathType,
    volume2: InputPathType,
    vox2ras_thresh: float | None = None,
    pix_thresh: float | None = None,
    allow_precision: bool = False,
    allow_resolution: bool = False,
    allow_vox2ras: bool = False,
    debug: bool = False,
    checkopts: bool = False,
    runner: Runner | None = None,
) -> MriVoldiffOutputs:
    """
    Determines whether two volumes are different in terms of pixel data, dimension,
    precision, resolution, or geometry.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        volume1: First input volume.
        volume2: Second input volume.
        vox2ras_thresh: Vox2RAS threshold value.
        pix_thresh: Pixel threshold value.
        allow_precision: Allow differences in precision.
        allow_resolution: Allow differences in resolution.
        allow_vox2ras: Allow differences in Vox2RAS.
        debug: Turn on debugging.
        checkopts: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriVoldiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_VOLDIFF_METADATA)
    cargs = []
    cargs.append("mri_voldiff")
    cargs.extend([
        "-v1",
        execution.input_file(volume1)
    ])
    cargs.extend([
        "-v2",
        execution.input_file(volume2)
    ])
    if vox2ras_thresh is not None:
        cargs.extend([
            "--vox2ras",
            str(vox2ras_thresh)
        ])
    if pix_thresh is not None:
        cargs.extend([
            "--pix",
            str(pix_thresh)
        ])
    if allow_precision:
        cargs.append("--allow-prec")
    if allow_resolution:
        cargs.append("--allow-res")
    if allow_vox2ras:
        cargs.append("--allow-vox2ras")
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    ret = MriVoldiffOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_VOLDIFF_METADATA",
    "MriVoldiffOutputs",
    "mri_voldiff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ISNIFTI_METADATA = Metadata(
    id="0ec07279947545d1155748f4d9a448ee304204a0.boutiques",
    name="isnifti",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class IsniftiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `isnifti(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def isnifti(
    infile: InputPathType,
    runner: Runner | None = None,
) -> IsniftiOutputs:
    """
    A simple tool to check if a file is a NIfTI image.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        infile: Input file to be checked if it is a NIfTI image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IsniftiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ISNIFTI_METADATA)
    cargs = []
    cargs.append("isnifti")
    cargs.append(execution.input_file(infile))
    ret = IsniftiOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ISNIFTI_METADATA",
    "IsniftiOutputs",
    "isnifti",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMAGE_INTENSITY_STATISTICS_METADATA = Metadata(
    id="ba7ab9e8e494076bff274459f3f86dfd1563d5d9.boutiques",
    name="ImageIntensityStatistics",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class ImageIntensityStatisticsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `image_intensity_statistics(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    intensity_statistics: OutputPathType
    """The output file containing intensity statistics."""


def image_intensity_statistics(
    image_dimension: int,
    input_image: InputPathType,
    label_image: InputPathType | None = None,
    runner: Runner | None = None,
) -> ImageIntensityStatisticsOutputs:
    """
    This tool computes intensity statistics of an input image, optionally given a
    label image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the image (e.g., 2D, 3D).
        input_image: The input image for which intensity statistics will be\
            computed.
        label_image: An optional label image which defines regions of interest.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImageIntensityStatisticsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMAGE_INTENSITY_STATISTICS_METADATA)
    cargs = []
    cargs.append("ImageIntensityStatistics")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(input_image))
    if label_image is not None:
        cargs.append(execution.input_file(label_image))
    ret = ImageIntensityStatisticsOutputs(
        root=execution.output_file("."),
        intensity_statistics=execution.output_file("intensity_statistics.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMAGE_INTENSITY_STATISTICS_METADATA",
    "ImageIntensityStatisticsOutputs",
    "image_intensity_statistics",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DCM2NIIX_AFNI_METADATA = Metadata(
    id="2b048e6ed8405f5110cc5399162aab212faa5c72.boutiques",
    name="dcm2niix_afni",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class Dcm2niixAfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dcm2niix_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    nifti_files: OutputPathType
    """The main output NIfTI files"""


def dcm2niix_afni(
    input_folder: str,
    compression_level: int | None = None,
    adjacent_dicoms: str | None = None,
    bids_sidecar: str | None = None,
    anonymize_bids: str | None = None,
    comment: str | None = None,
    directory_search_depth: int | None = None,
    export_format: str | None = None,
    filename_template: str | None = None,
    generate_defaults: str | None = None,
    ignore_images: str | None = None,
    lossless_scale: str | None = None,
    merge_slices: str | None = None,
    series_crc_number: list[str] | None = None,
    output_directory: str | None = None,
    phillips_scaling: str | None = None,
    rename_dicoms: str | None = None,
    single_file_mode: str | None = None,
    up_to_date: bool = False,
    verbose: str | None = None,
    write_behavior: int | None = None,
    crop_3d: str | None = None,
    gz_compress: str | None = None,
    big_endian: str | None = None,
    progress: str | None = None,
    ignore_trigger_times: bool = False,
    terse: bool = False,
    version: bool = False,
    xml_: bool = False,
    runner: Runner | None = None,
) -> Dcm2niixAfniOutputs:
    """
    DICOM to NIfTI converter optimized for AFNI.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_folder: Folder containing DICOM files.
        compression_level: GZ compression level (1=fastest..9=smallest, default\
            6).
        adjacent_dicoms: Adjacent DICOMs (images from same series always in\
            same folder) for faster conversion (n/y, default n).
        bids_sidecar: BIDS sidecar (y/n/o [o=only: no NIfTI], default y).
        anonymize_bids: Anonymize BIDS (y/n, default y).
        comment: Comment stored in NIfTI aux_file (provide up to 24 characters\
            e.g. '-c first_visit').
        directory_search_depth: Directory search depth. Convert DICOMs in\
            sub-folders of in_folder? (0..9, default 5).
        export_format: Export as NRRD (y) or MGH (o) instead of NIfTI (y/n/o,\
            default n).
        filename_template: Filename template for output (default '%f_%p_%t_%s').
        generate_defaults: Generate defaults file (y/n/o/i [o=only: reset and\
            write defaults; i=ignore: reset defaults], default n).
        ignore_images: Ignore derived, localizer and 2D images (y/n, default n).
        lossless_scale: Losslessly scale 16-bit integers to use dynamic range\
            (y/n/o, default o).
        merge_slices: Merge 2D slices from same series regardless of echo,\
            exposure, etc. (n/y or 0/1/2, default 2).
        series_crc_number: Only convert this series CRC number - can be used up\
            to 16 times (default convert all).
        output_directory: Output directory (omit to save to input folder).
        phillips_scaling: Philips precise float (not display) scaling (y/n,\
            default y).
        rename_dicoms: Rename instead of convert DICOMs (y/n, default n).
        single_file_mode: Single file mode, do not convert other images in\
            folder (y/n, default n).
        up_to_date: Up-to-date check.
        verbose: Verbose (n/y or 0/1/2, default 0).
        write_behavior: Write behavior for name conflicts (0=skip duplicates,\
            1=overwrite, 2=add suffix).
        crop_3d: Crop 3D acquisitions (y/n/i, default n, use 'i'gnore to\
            neither crop nor rotate 3D acquisitions).
        gz_compress: GZ compress images (y/o/i/n/3, default n) [y=pigz,\
            o=optimal pigz, i=internal:miniz, n=no, 3=no,3D].
        big_endian: Byte order (y/n/o, default o) [y=big-endian,\
            n=little-endian, o=optimal/native].
        progress: Slicer format progress information (y/n, default n).
        ignore_trigger_times: Disregard values in 0018, 1060 and 0020, 9153.
        terse: Omit filename post-fixes (can cause overwrites).
        version: Report version.
        xml_: Slicer format features.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Dcm2niixAfniOutputs`).
    """
    if series_crc_number is not None and not (len(series_crc_number) <= 16): 
        raise ValueError(f"Length of 'series_crc_number' must be less than 16 but was {len(series_crc_number)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(DCM2NIIX_AFNI_METADATA)
    cargs = []
    cargs.append("dcm2niix_afni")
    cargs.append(input_folder)
    if compression_level is not None:
        cargs.extend([
            "-1..-9",
            str(compression_level)
        ])
    if adjacent_dicoms is not None:
        cargs.extend([
            "-a",
            adjacent_dicoms
        ])
    if bids_sidecar is not None:
        cargs.extend([
            "-b",
            bids_sidecar
        ])
    if anonymize_bids is not None:
        cargs.extend([
            "-ba",
            anonymize_bids
        ])
    if comment is not None:
        cargs.extend([
            "-c",
            comment
        ])
    if directory_search_depth is not None:
        cargs.extend([
            "-d",
            str(directory_search_depth)
        ])
    if export_format is not None:
        cargs.extend([
            "-e",
            export_format
        ])
    if filename_template is not None:
        cargs.extend([
            "-f",
            filename_template
        ])
    if generate_defaults is not None:
        cargs.extend([
            "-g",
            generate_defaults
        ])
    if ignore_images is not None:
        cargs.extend([
            "-i",
            ignore_images
        ])
    if lossless_scale is not None:
        cargs.extend([
            "-l",
            lossless_scale
        ])
    if merge_slices is not None:
        cargs.extend([
            "-m",
            merge_slices
        ])
    if series_crc_number is not None:
        cargs.extend([
            "-n",
            *series_crc_number
        ])
    if output_directory is not None:
        cargs.extend([
            "-o",
            output_directory
        ])
    if phillips_scaling is not None:
        cargs.extend([
            "-p",
            phillips_scaling
        ])
    if rename_dicoms is not None:
        cargs.extend([
            "-r",
            rename_dicoms
        ])
    if single_file_mode is not None:
        cargs.extend([
            "-s",
            single_file_mode
        ])
    if up_to_date:
        cargs.append("-u")
    if verbose is not None:
        cargs.extend([
            "-v",
            verbose
        ])
    if write_behavior is not None:
        cargs.extend([
            "-w",
            str(write_behavior)
        ])
    if crop_3d is not None:
        cargs.extend([
            "-x",
            crop_3d
        ])
    if gz_compress is not None:
        cargs.extend([
            "-z",
            gz_compress
        ])
    if big_endian is not None:
        cargs.extend([
            "--big-endian",
            big_endian
        ])
    if progress is not None:
        cargs.extend([
            "--progress",
            progress
        ])
    if ignore_trigger_times:
        cargs.append("--ignore_trigger_times")
    if terse:
        cargs.append("--terse")
    if version:
        cargs.append("--version")
    if xml_:
        cargs.append("--xml")
    ret = Dcm2niixAfniOutputs(
        root=execution.output_file("."),
        nifti_files=execution.output_file("<OUTPUT_DIRECTORY>/*.nii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DCM2NIIX_AFNI_METADATA",
    "Dcm2niixAfniOutputs",
    "dcm2niix_afni",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SEGMENTATION_STATS_METADATA = Metadata(
    id="c496c4babb272fe5cf304c7413672a6f323ade3f.boutiques",
    name="mris_segmentation_stats",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSegmentationStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_segmentation_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    roc_output_file: OutputPathType
    """ROC curve file"""


def mris_segmentation_stats(
    overlay_name: str,
    segmentation_label_name: str,
    subjects: list[str],
    roc_file: str,
    runner: Runner | None = None,
) -> MrisSegmentationStatsOutputs:
    """
    Tool for calculating segmentation statistics.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        overlay_name: Overlay name for segmentation.
        segmentation_label_name: Segmentation label name.
        subjects: List of subjects to process.
        roc_file: File for ROC curve output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSegmentationStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SEGMENTATION_STATS_METADATA)
    cargs = []
    cargs.append("mris_segmentation_stats")
    cargs.append(overlay_name)
    cargs.append(segmentation_label_name)
    cargs.extend(subjects)
    cargs.append(roc_file)
    ret = MrisSegmentationStatsOutputs(
        root=execution.output_file("."),
        roc_output_file=execution.output_file(roc_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SEGMENTATION_STATS_METADATA",
    "MrisSegmentationStatsOutputs",
    "mris_segmentation_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APSEARCH_METADATA = Metadata(
    id="daa8fa19d4d15fe37e1fd44af2f41bbb1e0649d7.boutiques",
    name="apsearch",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ApsearchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `apsearch(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """File containing search results"""


def apsearch(
    search_term: str,
    file_output: InputPathType | None = None,
    verbose: bool = False,
    runner: Runner | None = None,
) -> ApsearchOutputs:
    """
    A tool for searching applications.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        search_term: Term to search.
        file_output: File to save the search results.
        verbose: Print detailed information during search.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ApsearchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APSEARCH_METADATA)
    cargs = []
    cargs.append("apsearch")
    cargs.append(search_term)
    if file_output is not None:
        cargs.append(execution.input_file(file_output))
    if verbose:
        cargs.append("-v")
    ret = ApsearchOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(file_output).name) if (file_output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APSEARCH_METADATA",
    "ApsearchOutputs",
    "apsearch",
]
